#
# spec file for package python-botocore
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-botocore
Version:        1.12.213
Release:        lp150.7.1
Summary:        Python interface for AWS
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/boto/botocore
Source:         https://files.pythonhosted.org/packages/source/b/botocore/botocore-%{version}.tar.gz
Patch0:         hide_py_pckgmgmt.patch
BuildRequires:  %{python_module docutils >= 0.10}
BuildRequires:  %{python_module jmespath < 1.0.0}
BuildRequires:  %{python_module jmespath >= 0.7.1}
BuildRequires:  %{python_module python-dateutil <= 3.0.0}
BuildRequires:  %{python_module python-dateutil >= 2.1}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module urllib3 < 1.26}
BuildRequires:  %{python_module urllib3 >= 1.20}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-docutils >= 0.10
Requires:       python-jmespath < 1.0.0
Requires:       python-jmespath >= 0.7.1
Requires:       python-python-dateutil <= 3.0.0
Requires:       python-python-dateutil >= 2.1
Requires:       python-requests
Requires:       python-six
Requires:       python-urllib3 < 1.26
Requires:       python-urllib3 >= 1.20
BuildArch:      noarch
%if 0%{?suse_version} <= 1315
# We need the ssl module, which is delivers by python and not python-base
BuildRequires:  python
%endif
# SECTION Testing requirements
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module requests}
BuildRequires:  %{python_module six}
# /SECTION
%python_subpackages

%description
A low-level interface to a growing number of Amazon Web Services.

%prep
%setup -q -n botocore-%{version}
%patch0 -p1
# remove bundled cacert.pem
rm botocore/cacert.pem
# remove bundled 3rd party Python modules
rm -r botocore/vendored/
# fix all imports:
sed -i 's/from botocore\.vendored //' botocore/*.py tests/functional/*.py tests/integration/*.py tests/unit/*.py
sed -i 's/botocore.vendored.requests.model.Response/requests.model.Response/' botocore/endpoint.py
sed -i 's/botocore\.vendored\.//' botocore/*.py tests/functional/*.py tests/integration/*.py tests/unit/*.py

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%python_expand nosetests-%{$python_bin_suffix} tests/unit

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/botocore/
%{python_sitelib}/botocore-%{version}-py%{py_ver}.egg-info

%changelog
* Thu Aug 22 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.12.213 (bsc#1146853, bsc#1146854)
  * api-change:``forecast``: Update forecast client to latest version
  * api-change:``forecastquery``: Update forecastquery client to latest version
  * api-change:``personalize-runtime``: Update personalize-runtime client to latest version
  * api-change:``elasticache``: Update elasticache client to latest version
  * api-change:``rekognition``: Update rekognition client to latest version
  * api-change:``sagemaker``: Update sagemaker client to latest version
  * api-change:``sqs``: Update sqs client to latest version
- from version 1.12.212
  * api-change:``sagemaker``: Update sagemaker client to latest version
  * api-change:``transfer``: Update transfer client to latest version
  * api-change:``appstream``: Update appstream client to latest version
  * api-change:``alexaforbusiness``: Update alexaforbusiness client to latest version
- from version 1.12.211
  * api-change:``appmesh``: Update appmesh client to latest version
  * api-change:``cur``: Update cur client to latest version
- from version 1.12.210
  * api-change:``robomaker``: Update robomaker client to latest version
  * api-change:``emr``: Update emr client to latest version
  * api-change:``ecs``: Update ecs client to latest version
- from version 1.12.209
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``appmesh``: Update appmesh client to latest version
  * api-change:``athena``: Update athena client to latest version
  * api-change:``codecommit``: Update codecommit client to latest version
  * api-change:``glue``: Update glue client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
- from version 1.12.208
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.207
  * api-change:``appsync``: Update appsync client to latest version
- from version 1.12.206
  * api-change:``autoscaling``: Update autoscaling client to latest version
  * api-change:``cloudwatch``: Update cloudwatch client to latest version
  * api-change:``application-autoscaling``: Update application-autoscaling client to latest version
  * api-change:``rekognition``: Update rekognition client to latest version
- from version 1.12.205
  * api-change:``guardduty``: Update guardduty client to latest version
  * api-change:``lex-runtime``: Update lex-runtime client to latest version
  * api-change:``redshift``: Update redshift client to latest version
  * api-change:``iot``: Update iot client to latest version
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
- from version 1.12.204
  * api-change:``lakeformation``: Update lakeformation client to latest version
  * api-change:``opsworkscm``: Update opsworkscm client to latest version
  * api-change:``glue``: Update glue client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
- from version 1.12.203
  * api-change:``application-insights``: Update application-insights client to latest version
- from version 1.12.202
  * api-change:``batch``: Update batch client to latest version
- from version 1.12.201
  * api-change:``datasync``: Update datasync client to latest version
  * api-change:``iot``: Update iot client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version  1.12.200
  * api-change:``sts``: Update sts client to latest version
  * enhancement:Credentials: Add support for a credential provider that
    handles resolving credentials via STS AssumeRoleWithWebIdentity
- from version 1.12.199
  * api-change:``polly``: Update polly client to latest version
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
  * api-change:``route53``: Update route53 client to latest version
- from version 1.12.198
  * bugfix:S3: Fix an issue that would cause S3 list_object_versions to
    sometimes fail parsing responses with certain key values.
  * api-change:``codecommit``: Update codecommit client to latest version
- from version 1.12.197
  * api-change:``ce``: Update ce client to latest version
  * api-change:``greengrass``: Update greengrass client to latest version
  * api-change:``glue``: Update glue client to latest version
  * api-change:``logs``: Update logs client to latest version
  * api-change:``mediaconnect``: Update mediaconnect client to latest version
  * api-change:``batch``: Update batch client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.196
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``ecr``: Update ecr client to latest version
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
- from version 1.12.195
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``sts``: Update sts client to latest version
  * api-change:``pinpoint``: Update pinpoint client to latest version
  * api-change:``glue``: Update glue client to latest version
- from version 1.12.194
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``secretsmanager``: Update secretsmanager client to latest version
- from version 1.12.193
  * api-change:``mq``: Update mq client to latest version
  * api-change:``shield``: Update shield client to latest version
- from version 1.12.192
  * bugfix:Dependency: Fixed dependency issue with broken docutils
    aws/aws-cli`#4332 <https://github.com/boto/botocore/issues/4332>`__
- from version 1.12.191
  * api-change:``sqs``: Update sqs client to latest version
  * api-change:``iotevents``: Update iotevents client to latest version
- from version 1.12.190
  * api-change:``comprehend``: Update comprehend client to latest version
  * api-change:``codedeploy``: Update codedeploy client to latest version
  * api-change:``elasticache``: Update elasticache client to latest version
  * api-change:``ecs``: Update ecs client to latest version
- from version 1.12.189
  * api-change:``config``: Update config client to latest version
  * api-change:``dms``: Update dms client to latest version
  * api-change:``autoscaling``: Update autoscaling client to latest version
- Refresh patches for new version
  + hide_py_pckgmgmt.patch
* Tue Jul 16 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.12.188
  * api-change:``iam``: Update iam client to latest version
  * api-change:``apigatewayv2``: Update apigatewayv2 client to latest version
  * api-change:``robomaker``: Update robomaker client to latest version
  * api-change:``es``: Update es client to latest version
- from version 1.12.187
  * api-change:``events``: Update events client to latest version
- from version 1.12.186
  * api-change:``quicksight``: Update quicksight client to latest version
  * api-change:``glacier``: Update glacier client to latest version
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
- from version 1.12.185
  * api-change:``efs``: Update efs client to latest version
  * api-change:``cloudwatch``: Update cloudwatch client to latest version
  * api-change:``amplify``: Update amplify client to latest version
  * api-change:``kinesis-video-archived-media``: Update kinesis-video-archived-media client to latest version
  * api-change:``gamelift``: Update gamelift client to latest version
  * api-change:``kinesisvideo``: Update kinesisvideo client to latest version
  * api-change:``waf``: Update waf client to latest version
  * api-change:``config``: Update config client to latest version
  * api-change:``waf-regional``: Update waf-regional client to latest version
- from version 1.12.184
  * api-change:``ce``: Update ce client to latest version
- from version 1.12.183
  * api-change:``swf``: Update swf client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``s3``: Update s3 client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.182
  * enhancement:CSM: Support configuration of the host used in client side metrics via AWS_CSM_HOST
  * api-change:``appstream``: Update appstream client to latest version
  * api-change:``mediastore``: Update mediastore client to latest version
- from version 1.12.181
  * api-change:``docdb``: Update docdb client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``organizations``: Update organizations client to latest version
  * api-change:``rds``: Update rds client to latest version
- from version 1.12.180
  * api-change:``alexaforbusiness``: Update alexaforbusiness client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``redshift``: Update redshift client to latest version
  * api-change:``workspaces``: Update workspaces client to latest version
* Fri Jun 28 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.12.179
  * api-change:``directconnect``: Update directconnect client to latest version
  * api-change:``pinpoint``: Update pinpoint client to latest version
  * api-change:``workspaces``: Update workspaces client to latest version
  * api-change:``ec2-instance-connect``: Update ec2-instance-connect client to latest version
- from version 1.12.178
  * api-change:``dynamodb``: Update dynamodb client to latest version
- from version 1.12.177
  * api-change:``codecommit``: Update codecommit client to latest version
  * api-change:``apigatewayv2``: Update apigatewayv2 client to latest version
- from version 1.12.176
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``eks``: Update eks client to latest version
- from version 1.12.175
  * api-change:``application-insights``: Update application-insights client to latest version
  * api-change:``securityhub``: Update securityhub client to latest version
  * api-change:``apigateway``: Update apigateway client to latest version
  * api-change:``elbv2``: Update elbv2 client to latest version
  * api-change:``fsx``: Update fsx client to latest version
  * api-change:``service-quotas``: Update service-quotas client to latest version
  * api-change:``resourcegroupstaggingapi``: Update resourcegroupstaggingapi client to latest version
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``apigatewayv2``: Update apigatewayv2 client to latest version
- from version 1.12.174
  * api-change:``devicefarm``: Update devicefarm client to latest version
  * api-change:``iam``: Update iam client to latest version
  * api-change:``mediapackage``: Update mediapackage client to latest version
  * api-change:``kinesis-video-media``: Update kinesis-video-media client to latest version
- from version 1.12.173
  * api-change:``health``: Update health client to latest version
  * api-change:``glue``: Update glue client to latest version
  * api-change:``iotevents-data``: Update iotevents-data client to latest version
  * api-change:``opsworks``: Update opsworks client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``acm-pca``: Update acm-pca client to latest version
* Thu Jun 20 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.12.172
  * api-change:``eks``: Update eks client to latest version
- from version 1.12.171
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``resourcegroupstaggingapi``: Update resourcegroupstaggingapi client to latest version
- from version 1.12.170
  * api-change:``neptune``: Update neptune client to latest version
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
  * api-change:``robomaker``: Update robomaker client to latest version
  * bugfix:Paginator: Fixes a bug where pagination tokens with three consecutive underscores would
    result in a parsing failure. Resolves boto/boto3`#1984 <https://github.com/boto/boto3/issues/1984>`__.
- from version 1.12.169
  * api-change:``cloudfront``: Update cloudfront client to latest version
  * api-change:``personalize``: Update personalize client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``appstream``: Update appstream client to latest version
- from version 1.12.168
  * api-change:``appmesh``: Update appmesh client to latest version
  * api-change:``elasticache``: Update elasticache client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``guardduty``: Update guardduty client to latest version
- from version 1.12.167
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
- Fix typo in spec file comment
- Remove bundled cacert.pem
* Wed Jun 12 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.12.166
  * api-change:``sagemaker``: Update sagemaker client to latest version
- from version 1.12.165
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``personalize-runtime``: Update personalize-runtime client to latest version
  * api-change:``codecommit``: Update codecommit client to latest version
  * api-change:``personalize-events``: Update personalize-events client to latest version
  * api-change:``personalize``: Update personalize client to latest version
- from version 1.12.164
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.163
  * api-change:``ecs``: Update ecs client to latest version
  * api-change:``organizations``: Update organizations client to latest version
  * api-change:``logs``: Update logs client to latest version
  * api-change:``dynamodb``: Update dynamodb client to latest version
  * api-change:``guardduty``: Update guardduty client to latest version
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``ses``: Update ses client to latest version
  * api-change:``mediaconnect``: Update mediaconnect client to latest version
- from version 1.12.162
  * api-change:``glue``: Update glue client to latest version
- from version 1.12.161
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
  * api-change:``s3``: Update s3 client to latest version
  * api-change:``elasticache``: Update elasticache client to latest version
  * api-change:``iam``: Update iam client to latest version
* Wed Jun  5 2019 Todd R <toddrme2178@gmail.com>
- Version update to 1.12.160
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
  * api-change:``s3``: Update s3 client to latest version
  * api-change:``elasticache``: Update elasticache client to latest version
  * api-change:``iam``: Update iam client to latest version
- Version update to 1.12.160
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``rds``: Update rds client to latest version
- Version update to 1.12.159
  * api-change:``iotevents-data``: Update iotevents-data client to latest version
  * api-change:``iotevents``: Update iotevents client to latest version
  * api-change:``pinpoint-email``: Update pinpoint-email client to latest version
  * api-change:``iotanalytics``: Update iotanalytics client to latest version
  * api-change:``codecommit``: Update codecommit client to latest version
  * api-change:``rds-data``: Update rds-data client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
  * api-change:``kafka``: Update kafka client to latest version
- Version update to 1.12.158
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``securityhub``: Update securityhub client to latest version
  * api-change:``iotthingsgraph``: Update iotthingsgraph client to latest version
  * api-change:``dlm``: Update dlm client to latest version
  * api-change:``codecommit``: Update codecommit client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- Version update to 1.12.157
  * api-change:``groundstation``: Update groundstation client to latest version
  * api-change:``transcribe``: Update transcribe client to latest version
  * api-change:``chime``: Update chime client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``waf``: Update waf client to latest version
  * api-change:``pinpoint-email``: Update pinpoint-email client to latest version
  * api-change:``robomaker``: Update robomaker client to latest version
  * api-change:``sts``: Update sts client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
- urllib3 is now a hard dependency
* Sat May 25 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.12.156 (boo#1136184)
  * api-change:``mediastore-data``: Update mediastore-data client to latest version
  * api-change:``codedeploy``: Update codedeploy client to latest version
  * api-change:``opsworkscm``: Update opsworkscm client to latest version
- from version 1.12.155
  * api-change:``waf-regional``: Update waf-regional client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.154
  * api-change:``efs``: Update efs client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``apigateway``: Update apigateway client to latest version
  * api-change:``worklink``: Update worklink client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
  * api-change:``devicefarm``: Update devicefarm client to latest version
  * api-change:``budgets``: Update budgets client to latest version
- from version 1.12.153
  * api-change:``datasync``: Update datasync client to latest version
  * api-change:``alexaforbusiness``: Update alexaforbusiness client to latest version
- from version 1.12.152
  * api-change:``kafka``: Update kafka client to latest version
  * api-change:``meteringmarketplace``: Update meteringmarketplace client to latest version
  * api-change:``mediapackage-vod``: Update mediapackage-vod client to latest version
- from version 1.12.151
  * api-change:``appstream``: Update appstream client to latest version
- from 1.12.150
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``s3``: Update s3 client to latest version
- from version 1.12.149
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``transcribe``: Update transcribe client to latest version
  * api-change:``mediapackage``: Update mediapackage client to latest version
  * api-change:``codepipeline``: Update codepipeline client to latest version
  * enhancement:Environment Variables: Ignore env var credentials is values are
    empty (`#1680 <https://github.com/boto/botocore/issues/1680>`__)
  * api-change:``rds``: Update rds client to latest version
- from version 1.12.148
  * api-change:``comprehend``: Update comprehend client to latest version
  * api-change:``chime``: Update chime client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- Refresh patches for new version
  + hide_py_pckgmgmt.patch
- Update Requires in spec file from setup.py
* Tue May 14 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.12.147
  * api-change:``datasync``: Update datasync client to latest version
  * api-change:``iotanalytics``: Update iotanalytics client to latest version
  * api-change:``lambda``: Update lambda client to latest version
- from version 1.12.146
  * api-change:``glue``: Update glue client to latest version
  * api-change:``sts``: Update sts client to latest version
- from version 1.12.145
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
  * api-change:``eks``: Update eks client to latest version
  * api-change:``sagemaker``: Update sagemaker client to latest version
  * api-change:``kinesisanalytics``: Update kinesisanalytics client to latest version
  * api-change:``kinesisanalyticsv2``: Update kinesisanalyticsv2 client to latest version
- from version 1.12.144
  * api-change:``appsync``: Update appsync client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``alexaforbusiness``: Update alexaforbusiness client to latest version
- from version 1.12.143
  * api-change:``config``: Update config client to latest version
  * api-change:``iam``: Update iam client to latest version
  * api-change:``sts``: Update sts client to latest version
  * api-change:``codepipeline``: Update codepipeline client to latest version
- from version 1.12.142
  * api-change:``workmail``: Update workmail client to latest version
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``cognito-idp``: Update cognito-idp client to latest version
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
- from version 1.12.141
  * api-change:``alexaforbusiness``: Update alexaforbusiness client to latest version
  * api-change:``kms``: Update kms client to latest version
- from version 1.12.140
  * api-change:``ecs``: Update ecs client to latest version
  * api-change:``xray``: Update xray client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.139
  * api-change:``neptune``: Update neptune client to latest version
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
  * api-change:``managedblockchain``: Update managedblockchain client to latest version
  * api-change:``s3control``: Update s3control client to latest version
  * api-change:``directconnect``: Update directconnect client to latest version
  * api-change:``codepipeline``: Update codepipeline client to latest version
- from version 1.12.138
  * api-change:``transfer``: Update transfer client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.137
  * api-change:``iam``: Update iam client to latest version
  * api-change:``sns``: Update sns client to latest version
- from version 1.12.136
  * api-change:``gamelift``: Update gamelift client to latest version
  * api-change:``workspaces``: Update workspaces client to latest version
  * api-change:``dynamodb``: Update dynamodb client to latest version
  * api-change:``inspector``: Update inspector client to latest version
  * api-change:``lambda``: Update lambda client to latest version
  * api-change:``batch``: Update batch client to latest version
- from version 1.12.135
  * api-change:``mediatailor``: Update mediatailor client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``cloudformation``: Update cloudformation client to latest version
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
  * api-change:``route53``: Update route53 client to latest version
  * api-change:``alexaforbusiness``: Update alexaforbusiness client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``mediaconnect``: Update mediaconnect client to latest version
  * api-change:``textract``: Update textract client to latest version
- from version 1.12.134
  * api-change:``resource-groups``: Update resource-groups client to latest version
  * api-change:``transcribe``: Update transcribe client to latest version
  * api-change:``workspaces``: Update workspaces client to latest version
- from version 1.12.133
  * api-change:``kafka``: Update kafka client to latest version
  * api-change:``cognito-idp``: Update cognito-idp client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``worklink``: Update worklink client to latest version
  * api-change:``workspaces``: Update workspaces client to latest version
  * api-change:``discovery``: Update discovery client to latest version
  * api-change:``organizations``: Update organizations client to latest version
- from version 1.12.132
  * api-change:``polly``: Update polly client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.131
  * api-change:``organizations``: Update organizations client to latest version
  * api-change:``mq``: Update mq client to latest version
  * api-change:``redshift``: Update redshift client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
  * api-change:``cloudwatch``: Update cloudwatch client to latest version
  * api-change:``cognito-idp``: Update cognito-idp client to latest version
- from 1.12.130
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
  * api-change:``glue``: Update glue client to latest version
  * api-change:``comprehend``: Update comprehend client to latest version
  * api-change:``iot1click-devices``: Update iot1click-devices client to latest version
  * api-change:``medialive``: Update medialive client to latest version
- from version 1.12.129
  * api-change:``eks``: Update eks client to latest version
  * api-change:``iam``: Update iam client to latest version
- from version 1.12.128
  * api-change:``batch``: Update batch client to latest version
  * api-change:``comprehend``: Update comprehend client to latest version
* Wed Apr  3 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.12.127
  * api-change:``securityhub``: Update securityhub client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``acm``: Update acm client to latest version
- from version 1.12.126
  * api-change:``emr``: Update emr client to latest version
  * api-change:``ssm``: Update ssm client to latest version
- from version 1.12.125
  * api-change:``comprehend``: Update comprehend client to latest version
  * api-change:``cloudwatch``: Update cloudwatch client to latest version
  * api-change:``greengrass``: Update greengrass client to latest version
- from version 1.12.124
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``pinpoint-email``: Update pinpoint-email client to latest version
  * api-change:``workspaces``: Update workspaces client to latest version
- from version 1.12.123
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``appmesh``: Update appmesh client to latest version
  * api-change:``ecs``: Update ecs client to latest version
  * api-change:``elbv2``: Update elbv2 client to latest version
  * api-change:``transfer``: Update transfer client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
  * api-change:``s3``: Update s3 client to latest version
- from version 1.12.122
  * api-change:``workmail``: Update workmail client to latest version
  * api-change:``glue``: Update glue client to latest version
- from version 1.12.121
  * api-change:``iotanalytics``: Update iotanalytics client to latest version
  * api-change:``robomaker``: Update robomaker client to latest version
  * api-change:``directconnect``: Update directconnect client to latest version
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
  * api-change:``transcribe``: Update transcribe client to latest version
  * api-change:``fms``: Update fms client to latest version
  * api-change:``iot1click-devices``: Update iot1click-devices client to latest version
- from version 1.12.120
  * api-change:``iot1click-projects``: Update iot1click-projects client to latest version
  * api-change:``transcribe``: Update transcribe client to latest version
- from version 1.12.119
  * api-change:``iot``: Update iot client to latest version
  * api-change:``lightsail``: Update lightsail client to latest version
  * api-change:``autoscaling``: Update autoscaling client to latest version
  * api-change:``events``: Update events client to latest version
  * api-change:``cognito-idp``: Update cognito-idp client to latest version
- from version 1.12.118
  * api-change:``cognito-identity``: Update cognito-identity client to latest version
  * api-change:``codepipeline``: Update codepipeline client to latest version
  * api-change:``meteringmarketplace``: Update meteringmarketplace client to latest version
- from version 1.12.117
  * api-change:``config``: Update config client to latest version
  * api-change:``eks``: Update eks client to latest version
- from version 1.12.116
  * api-change:``dms``: Update dms client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``chime``: Update chime client to latest version
- from version 1.12.115
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``config``: Update config client to latest version
  * api-change:``acm``: Update acm client to latest version
  * api-change:``iot``: Update iot client to latest version
  * api-change:``acm-pca``: Update acm-pca client to latest version
  * api-change:``cloudwatch``: Update cloudwatch client to latest version
  * api-change:``sagemaker``: Update sagemaker client to latest version
- from version 1.12.114
  * api-change:``config``: Update config client to latest version
  * api-change:``logs``: Update logs client to latest version
- from version 1.12.113
  * api-change:``serverlessrepo``: Update serverlessrepo client to latest version
- from version 1.12.112
  * api-change:``iot``: Update iot client to latest version
  * api-change:``quicksight``: Update quicksight client to latest version
  * api-change:``glue``: Update glue client to latest version
  * api-change:``ce``: Update ce client to latest version
  * api-change:``elasticbeanstalk``: Update elasticbeanstalk client to latest version
  * api-change:``rekognition``: Update rekognition client to latest version
- from version 1.12.111
  * api-change:``s3``: Update s3 client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``sagemaker``: Update sagemaker client to latest version
- from version 1.12.110
  * api-change:``gamelift``: Update gamelift client to latest version
  * api-change:``greengrass``: Update greengrass client to latest version
  * api-change:``appmesh``: Update appmesh client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``autoscaling``: Update autoscaling client to latest version
  * api-change:``ecs``: Update ecs client to latest version
- from version 1.12.109
  * api-change:``directconnect``: Update directconnect client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.108
  * api-change:``textract``: Update textract client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``codedeploy``: Update codedeploy client to latest version
- from version 1.12.107
  * api-change:``mediapackage``: Update mediapackage client to latest version
  * api-change:``ssm``: Update ssm client to latest version
- from version 1.12.106
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``autoscaling-plans``: Update autoscaling-plans client to latest version
- from version 1.12.105
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``apigatewayv2``: Update apigatewayv2 client to latest version
  * api-change:``alexaforbusiness``: Update alexaforbusiness client to latest version
  * api-change:``application-autoscaling``: Update
    application-autoscaling client to latest version
- from version 1.12.104
  * api-change:``waf-regional``: Update waf-regional client to latest version
  * api-change:``waf``: Update waf client to latest version
- from version 1.12.103
  * api-change:``discovery``: Update discovery client to latest version
  * api-change:``organizations``: Update organizations client to latest version
  * api-change:``resource-groups``: Update resource-groups client to latest version
  * api-change:``opsworkscm``: Update opsworkscm client to latest version
  * api-change:``pinpoint``: Update pinpoint client to latest version
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
  * api-change:``cur``: Update cur client to latest version
- from version 1.12.102
  * api-change:``elbv2``: Update elbv2 client to latest version
  * api-change:``mediastore``: Update mediastore client to latest version
  * api-change:``ce``: Update ce client to latest version
  * api-change:``autoscaling``: Update autoscaling client to latest version
- from version 1.12.101
  * api-change:``athena``: Update athena client to latest version
  * api-change:``glue``: Update glue client to latest version
  * api-change:``stepfunctions``: Update stepfunctions client to latest version
  * api-change:``cloud9``: Update cloud9 client to latest version
- from version 1.12.100
  * api-change:``kinesis-video-archived-media``: Update
    kinesis-video-archived-media client to latest version
  * api-change:``workdocs``: Update workdocs client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``cloudwatch``: Update cloudwatch client to latest version
  * api-change:``organizations``: Update organizations client to latest version
  * api-change:``kinesisvideo``: Update kinesisvideo client to latest version
  * api-change:``kinesis-video-media``: Update kinesis-video-media
    client to latest version
  * api-change:``transfer``: Update transfer client to latest version
- from version 1.12.99
  * api-change:``codecommit``: Update codecommit client to latest version
  * api-change:``directconnect``: Update directconnect client to latest version
  * api-change:``medialive``: Update medialive client to latest version
- from version 1.12.98
  * api-change:``iot``: Update iot client to latest version
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``ds``: Update ds client to latest version
  * enhancement:Paginator: Add additional paginators for CloudFormation
  * api-change:``efs``: Update efs client to latest version
- from version 1.12.97
  * api-change:``athena``: Update athena client to latest version
  * api-change:``secretsmanager``: Update secretsmanager client to latest version
* Tue Mar  5 2019 Sean Marlow <sean.marlow@suse.com>
- Version update to 1.12.96
  * api-change:chime: Update chime client to latest version
  * api-change:application-autoscaling: Update application
    autoscaling client to latest version
  * api-change:iot: Update iot client to latest version
- Version update to 1.12.95
  * api-change:kinesisvideo: Update kinesisvideo client to latest
    version
  * api-change:ec2: Update ec2 client to latest version
- Version update to 1.12.94
  * api-change:rekognition: Update rekognition client to latest
    version
  * api-change:mediatailor: Update mediatailor client to latest
    version
  * api-change:efs: Update efs client to latest version
* Wed Feb 13 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.12.93
  * api-change:``lambda``: Update lambda client to latest version
- from version 1.12.92
  * api-change:``appstream``: Update appstream client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``mediapackage``: Update mediapackage client to latest version
- from version 1.12.91
  * api-change:``discovery``: Update discovery client to latest version
  * api-change:``ecs``: Update ecs client to latest version
  * api-change:``dlm``: Update dlm client to latest version
- from version 1.12.90
  * api-change:``es``: Update es client to latest version
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``gamelift``: Update gamelift client to latest version
  * api-change:``robomaker``: Update robomaker client to latest version
- from version 1.12.89
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``fsx``: Update fsx client to latest version
- from version 1.12.88
  * api-change:``shield``: Update shield client to latest version
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.87
  * api-change:``ecs``: Update ecs client to latest version
  * api-change:``application-autoscaling``: Update application-autoscaling client to latest version
  * api-change:``workspaces``: Update workspaces client to latest version
  * api-change:``codecommit``: Update codecommit client to latest version
- from version 1.12.86
  * api-change:``devicefarm``: Update devicefarm client to latest version
  * api-change:``codecommit``: Update codecommit client to latest version
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``mediaconnect``: Update mediaconnect client to latest version
- from version 1.12.85
  * api-change:``logs``: Update logs client to latest version
  * api-change:``elbv2``: Update elbv2 client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``sms-voice``: Update sms-voice client to latest version
  * api-change:``ecr``: Update ecr client to latest version
* Thu Jan 24 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.12.84
  * api-change:``worklink``: Update worklink client to latest version
  * api-change:``apigatewaymanagementapi``: Update apigatewaymanagementapi client to latest version
  * api-change:``acm-pca``: Update acm-pca client to latest version
- from version 1.12.83
  * api-change:``appstream``: Update appstream client to latest version
  * api-change:``discovery``: Update discovery client to latest version
  * api-change:``dms``: Update dms client to latest version
  * api-change:``fms``: Update fms client to latest version
  * api-change:``ssm``: Update ssm client to latest version
- from version 1.12.82
  * api-change:``glue``: Update glue client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.81
  * api-change:``lightsail``: Update lightsail client to latest version
  * api-change:``lambda``: Update lambda client to latest version
  * api-change:``pinpoint``: Update pinpoint client to latest version
  * api-change:``rekognition``: Update rekognition client to latest version
- from version 1.12.80
  * api-change:``dynamodb``: Update dynamodb client to latest version
  * api-change:``ce``: Update ce client to latest version
  * api-change:``backup``: Update backup client to latest version
- from version 1.12.79
  * api-change:``storagegateway``: Update storagegateway client to latest version
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
- from version 1.12.78
  * api-change:``rds-data``: Update rds-data client to latest version
  * api-change:``emr``: Update emr client to latest version
- from version 1.12.77
  * api-change:``iot``: Update iot client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``codedeploy``: Update codedeploy client to latest version
  * api-change:``sagemaker``: Update sagemaker client to latest version
- from version 1.12.76
  * api-change:``docdb``: Update docdb client to latest version
  * api-change:``redshift``: Update redshift client to latest version
- from version 1.12.75
  * api-change:``appmesh``: Update appmesh client to latest version
- Refresh patches for new version
  + hide_py_pckgmgmt.patch
* Sun Jan  6 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.12.74
  * api-change:``ecs``: Update ecs client to latest version
  * api-change:``devicefarm``: Update devicefarm client to latest version
- from version 1.12.73
  * api-change:``iotanalytics``: Update iotanalytics client to latest version
- from version 1.12.72
  * enhancement:Paginator: Added over 400 new paginators.
  * api-change:``opsworkscm``: Update opsworkscm client to latest version
- from version 1.12.71
  * api-change:``acm-pca``: Update acm-pca client to latest version
  * api-change:``dynamodb``: Update dynamodb client to latest version
  * api-change:``sms-voice``: Update sms-voice client to latest version
  * api-change:``stepfunctions``: Update stepfunctions client to latest version
- from version 1.12.70
  * api-change:``medialive``: Update medialive client to latest version
  * enhancement:EndpointDiscovery: Add a config option, ``endpoint_discovery_enabled``,
    for automatically discovering endpoints
  * api-change:``comprehend``: Update comprehend client to latest version
  * api-change:``firehose``: Update firehose client to latest version
  * api-change:``transcribe``: Update transcribe client to latest version
  * api-change:``cognito-idp``: Update cognito-idp client to latest version
- from version 1.12.69
  * api-change:``sagemaker``: Update sagemaker client to latest version
  * api-change:``waf-regional``: Update waf-regional client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``waf``: Update waf client to latest version
- from version 1.12.68
  * api-change:``apigatewayv2``: Update apigatewayv2 client to latest version
  * bugfix:Credentials: Fixes an issue where credentials would be checked when creating
    an anonymous client. Fixes `#1472 <https://github.com/boto/botocore/issues/1472>`__
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``elasticbeanstalk``: Update elasticbeanstalk client to latest version
  * api-change:``globalaccelerator``: Update globalaccelerator client to latest version
  * enhancement:StreamingBody: Support iterating lines from a streaming response body with CRLF line endings
  * api-change:``apigatewaymanagementapi``: Update apigatewaymanagementapi client to latest version
- from version 1.12.67
  * api-change:``quicksight``: Update quicksight client to latest version
  * api-change:``ecr``: Update ecr client to latest version
- from version 1.12.66
  * api-change:``alexaforbusiness``: Update alexaforbusiness client to latest version
  * api-change:``redshift``: Update redshift client to latest version
  * api-change:``cloudformation``: Update cloudformation client to latest version
- from version 1.12.65
  * api-change:``organizations``: Update organizations client to latest version
  * api-change:``pinpoint-email``: Update pinpoint-email client to latest version
- from version 1.12.64
  * api-change:``route53``: Update route53 client to latest version
  * api-change:``glue``: Update glue client to latest version
  * api-change:``sagemaker``: Update sagemaker client to latest version
  * api-change:``eks``: Update eks client to latest version
- from version 1.12.63
  * api-change:``mediastore``: Update mediastore client to latest version
  * api-change:``ecs``: Update ecs client to latest version
  * api-change:``connect``: Update connect client to latest version
- from version 1.12.62
  * api-change:``ec2``: Update ec2 client to latest version
  * enhancement:AssumeRole: Add support for duration_seconds when assuming a role
    in the config file (`#1600 <https://github.com/boto/botocore/issues/1600>`__).
  * api-change:``iam``: Update iam client to latest version
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
  * api-change:``alexaforbusiness``: Update alexaforbusiness client to latest version
- from version 1.12.61
  * api-change:``elbv2``: Update elbv2 client to latest version
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``rds``: Update rds client to latest version
- from version 1.12.60
  * api-change:``mq``: Update mq client to latest version
  * api-change:``ce``: Update ce client to latest version
  * api-change:``mediatailor``: Update mediatailor client to latest version
- from version 1.12.59
  * api-change:``health``: Update health client to latest version
  * api-change:``s3``: Update s3 client to latest version
- from version 1.12.58
  * api-change:``devicefarm``: Update devicefarm client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
  * api-change:``servicecatalog``: Update servicecatalog client to latest version-
* Mon Dec  3 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.12.57 (bsc#1118021, bsc#1118027)
  * bugfix:s3: Add md5 header injection to new operations that require it
  * api-change:``s3``: Update s3 client to latest version
- from version 1.12.56
  * api-change:``elbv2``: Update elbv2 client to latest version
  * api-change:``stepfunctions``: Update stepfunctions client to latest version
  * api-change:``xray``: Update xray client to latest version
  * api-change:``lambda``: Update lambda client to latest version
  * api-change:``events``: Update events client to latest version
  * api-change:``serverlessrepo``: Update serverlessrepo client to latest version
  * api-change:``kafka``: Update kafka client to latest version
  * api-change:``s3``: Update s3 client to latest version
- from version 1.12.55
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``appmesh``: Update appmesh client to latest version
  * api-change:``license-manager``: Update license-manager client to latest version
  * api-change:``servicediscovery``: Update servicediscovery client to latest version
  * api-change:``sagemaker``: Update sagemaker client to latest version
  * api-change:``lightsail``: Update lightsail client to latest version
- from version 1.12.54
  * api-change:``securityhub``: Update securityhub client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``fsx``: Update fsx client to latest version
  * api-change:``dynamodb``: Update dynamodb client to latest version
- from version 1.12.53
  * api-change:``meteringmarketplace``: Update meteringmarketplace client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``codedeploy``: Update codedeploy client to latest version
  * api-change:``translate``: Update translate client to latest version
  * api-change:``logs``: Update logs client to latest version
  * api-change:``kinesisanalytics``: Update kinesisanalytics client to latest version
  * api-change:``comprehendmedical``: Update comprehendmedical client to latest version
  * api-change:``mediaconnect``: Update mediaconnect client to latest version
  * api-change:``kinesisanalyticsv2``: Update kinesisanalyticsv2 client to latest version
  * api-change:``ecs``: Update ecs client to latest version
- from version 1.12.52
  * api-change:``iot``: Update iot client to latest version
  * api-change:``sms``: Update sms client to latest version
  * api-change:``s3``: Update s3 client to latest version
  * api-change:``iotanalytics``: Update iotanalytics client to latest version
  * api-change:``greengrass``: Update greengrass client to latest version
  * api-change:``kms``: Update kms client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``globalaccelerator``: Update globalaccelerator client to latest version
- from version 1.12.51
  * api-change:``amplify``: Update amplify client to latest version
  * api-change:``transfer``: Update transfer client to latest version
  * api-change:``snowball``: Update snowball client to latest version
  * api-change:``robomaker``: Update robomaker client to latest version
  * api-change:``s3``: Update s3 client to latest version
  * api-change:``datasync``: Update datasync client to latest version
- from version 1.12.50
  * api-change:``rekognition``: Update rekognition client to latest version
- from version 1.12.49
  * api-change:``autoscaling-plans``: Update autoscaling-plans client to latest version
  * api-change:``xray``: Update xray client to latest version
  * api-change:``devicefarm``: Update devicefarm client to latest version
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``redshift``: Update redshift client to latest version
  * api-change:``rds-data``: Update rds-data client to latest version
  * api-change:``appsync``: Update appsync client to latest version
  * api-change:``cloudwatch``: Update cloudwatch client to latest version
  * api-change:``quicksight``: Update quicksight client to latest version
  * api-change:``cloudfront``: Update cloudfront client to latest version
- from version 1.12.48
  * api-change:``lightsail``: Update lightsail client to latest version
  * api-change:``workspaces``: Update workspaces client to latest version
  * api-change:``workdocs``: Update workdocs client to latest version
  * api-change:``batch``: Update batch client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``devicefarm``: Update devicefarm client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``cloudformation``: Update cloudformation client to latest version
  * api-change:``lambda``: Update lambda client to latest version
  * api-change:``config``: Update config client to latest version
  * api-change:``cloudtrail``: Update cloudtrail client to latest version
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
  * api-change:``iot``: Update iot client to latest version
- from version 1.12.47
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``comprehend``: Update comprehend client to latest version
  * api-change:``workspaces``: Update workspaces client to latest version
  * api-change:``ce``: Update ce client to latest version
  * api-change:``ecs``: Update ecs client to latest version
- from version 1.12.46
  * api-change:``s3``: Update s3 client to latest version
  * api-change:``sms-voice``: Update sms-voice client to latest version
  * api-change:``redshift``: Update redshift client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``dms``: Update dms client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``s3control``: Update s3control client to latest version
  * api-change:``directconnect``: Update directconnect client to latest version
  * api-change:``ram``: Update ram client to latest version
  * api-change:``pinpoint``: Update pinpoint client to latest version
  * api-change:``route53resolver``: Update route53resolver client to latest version
  * api-change:``comprehend``: Update comprehend client to latest version
  * api-change:``transcribe``: Update transcribe client to latest version
  * api-change:``ecs``: Update ecs client to latest version
  * api-change:``iam``: Update iam client to latest version
- from version 1.12.45
  * api-change:``resource-groups``: Update resource-groups client to latest version
  * api-change:``autoscaling``: Update autoscaling client to latest version
  * api-change:``mediatailor``: Update mediatailor client to latest version
  * api-change:``sns``: Update sns client to latest version
  * api-change:``sagemaker``: Update sagemaker client to latest version
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.44
  * api-change:``chime``: Update chime client to latest version
  * api-change:``budgets``: Update budgets client to latest version
  * api-change:``redshift``: Update redshift client to latest version
- from version 1.12.43
  * api-change:``polly``: Update polly client to latest version
  * api-change:``batch``: Update batch client to latest version
  * api-change:``firehose``: Update firehose client to latest version
  * api-change:``cloudformation``: Update cloudformation client to latest version
  * api-change:``budgets``: Update budgets client to latest version
  * api-change:``codepipeline``: Update codepipeline client to latest version
  * api-change:``rds``: Update rds client to latest version
- from version 1.12.42
  * api-change:``mediapackage``: Update mediapackage client to latest version
- from version 1.12.41
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``dlm``: Update dlm client to latest version
  * api-change:``events``: Update events client to latest version
- from version 1.12.40
  * api-change:``dms``: Update dms client to latest version
  * api-change:``ce``: Update ce client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.39
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``pinpoint``: Update pinpoint client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``pinpoint-email``: Update pinpoint-email client to latest version
  * api-change:``apigateway``: Update apigateway client to latest version
  * api-change:``waf-regional``: Update waf-regional client to latest version
  * bugfix:session config: Added the default session configuration
    tuples back to session.session_vars_map.
* Wed Nov  7 2018 Robert Schweikert <rjschwei@suse.com>
- Fix build for openSUSE Leap 42.3
  + urllib3 needs the ssl module, which in Leap 42.3 is delivered by python
    and not python-base. Set explicit build dependency on python
* Tue Nov  6 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.12.38
  * api-change:``eks``: Update eks client to latest version
  * enhancement:Configuration: Added new configuration provider methods
    allowing for more flexibility in how a botocore session loads a
    particular configuration value.
  * api-change:``serverlessrepo``: Update serverlessrepo client to latest version
- from version 1.12.37
  * api-change:``rekognition``: Update rekognition client to latest version
  * api-change:``clouddirectory``: Update clouddirectory client to latest version
- from version 1.12.36
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
  * enhancement:Exceptions: Add the ability to pickle botocore exceptions
    (`834 <https://github.com/boto/botocore/issues/834>`__)
- from version 1.12.35
  * api-change:``mediastore-data``: Update mediastore-data client to latest version
  * api-change:``secretsmanager``: Update secretsmanager client to latest version
  * api-change:``greengrass``: Update greengrass client to latest version
  * api-change:``config``: Update config client to latest version
- from version 1.12.34
  * api-change:``chime``: Update chime client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``dms``: Update dms client to latest version
- from version 1.12.33
  * api-change:``sagemaker``: Update sagemaker client to latest version
  * api-change:``alexaforbusiness``: Update alexaforbusiness client to latest version
  * api-change:``ssm``: Update ssm client to latest version
- from version 1.12.32
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.31
  * api-change:``codestar``: Update codestar client to latest version
  * api-change:``alexaforbusiness``: Update alexaforbusiness client to latest version
- from version 1.12.30
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.29
  * api-change:``inspector``: Update inspector client to latest version
  * api-change:``shield``: Update shield client to latest version
- from version 1.12.28
  * api-change:``workspaces``: Update workspaces client to latest version
  * api-change:``ssm``: Update ssm client to latest version
- from version 1.12.27
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``route53``: Update route53 client to latest version
  * api-change:``appstream``: Update appstream client to latest version
- from version 1.12.26
  * api-change:``events``: Update events client to latest version
  * api-change:``apigateway``: Update apigateway client to latest version
- from version 1.12.25
  * api-change:``glue``: Update glue client to latest version
  * api-change:``lightsail``: Update lightsail client to latest version
  * api-change:``resource-groups``: Update resource-groups client to latest version
- from version 1.12.24
  * api-change:``rds``: Update rds client to latest version
  * api-change:``lambda``: Update lambda client to latest version
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
- from version 1.12.23
  * api-change:``cloudtrail``: Update cloudtrail client to latest version
- from version 1.12.22
  * api-change:``athena``: Update athena client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``transcribe``: Update transcribe client to latest version
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
  * api-change:``directconnect``: Update directconnect client to latest version
- from version 1.12.21
  * api-change:``transcribe``: Update transcribe client to latest version
  * api-change:``comprehend``: Update comprehend client to latest version
  * api-change:``es``: Update es client to latest version
- from version 1.12.20
  * enhancement:TLS: Added support for configuring a client certificate
    and key when establishing TLS connections.
  * api-change:``ssm``: Update ssm client to latest version
  * bugfix:InstanceMetadataFetcher: Fix failure to retry on empty credentials
    and invalid JSON returned from IMDS `1049 <https://github.com/boto/botocore/issues/1049>`__
    `1403 <https://github.com/boto/botocore/issues/1403>`__
- from version 1.12.19
  * api-change:``iot``: Update iot client to latest version
  * api-change:``iot-jobs-data``: Update iot-jobs-data client to latest version
- from version 1.12.18
  * api-change:``ds``: Update ds client to latest version
- from version 1.12.17
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * enhancement:HTTP Session: Added the ability to enable TCP Keepalive via the
    shared config file's ``tcp_keepalive`` option.
  * api-change:``apigateway``: Update apigateway client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
- from version 1.12.16
  * api-change:``sagemaker``: Update sagemaker client to latest version
  * api-change:``secretsmanager``: Update secretsmanager client to latest version
- from version 1.12.15
  * api-change:``rekognition``: Update rekognition client to latest version
  * api-change:``guardduty``: Update guardduty client to latest version
- from version 1.12.14
  * api-change:``codestar``: Update codestar client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.13
  * api-change:``mq``: Update mq client to latest version
  * api-change:``apigateway``: Update apigateway client to latest version
  * enhancement:Event: Add the `before-send` event which allows finalized requests
    to be inspected before being sent across the wire and allows for custom
    responses to be returned.
  * api-change:``codecommit``: Update codecommit client to latest version
- from version 1.12.12
  * api-change:``sqs``: Update sqs client to latest version
  * api-change:``glue``: Update glue client to latest version
  * api-change:``opsworkscm``: Update opsworkscm client to latest version
  * api-change:``rds``: Update rds client to latest version
- from version 1.12.11
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``cloudfront``: Update cloudfront client to latest version
  * api-change:``ds``: Update ds client to latest version
- from version 1.12.10
  * api-change:``connect``: Update connect client to latest version
  * api-change:``rds``: Update rds client to latest version
- from version 1.12.9
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
- from version 1.12.8
  * api-change:``rds``: Update rds client to latest version
  * api-change:``ds``: Update ds client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- from version 1.12.7
  * api-change:``cloudwatch``: Update cloudwatch client to latest version
  * api-change:``s3``: Update s3 client to latest version
  * api-change:``organizations``: Update organizations client to latest version
- from version 1.12.6
  * bugfix:Serialization: Fixes `#1557 <https://github.com/boto/botocore/issues/1557>`__.
    Fixed a regression in serialization where request bodies would be improperly encoded.
  * api-change:``es``: Update es client to latest version
  * api-change:``rekognition``: Update rekognition client to latest version
- from version 1.12.5
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``elastictranscoder``: Update elastictranscoder client to latest version
  * api-change:``ecs``: Update ecs client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``cloudwatch``: Update cloudwatch client to latest version
  * api-change:``secretsmanager``: Update secretsmanager client to latest version
  * api-change:``elasticache``: Update elasticache client to latest version
- from version 1.12.4
  * enhancement:s3: Adds encoding and decoding handlers for ListObjectsV2
    `#1552 <https://github.com/boto/botocore/issues/1552>`__
  * api-change:``polly``: Update polly client to latest version
- from version 1.12.3
  * api-change:``ses``: Update ses client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``fms``: Update fms client to latest version
  * api-change:``connect``: Update connect client to latest version
- from version 1.12.2
  * api-change:``opsworkscm``: Update opsworkscm client to latest version
  * api-change:``ssm``: Update ssm client to latest version
- from version 1.12.1
  * api-change:``redshift``: Update redshift client to latest version
  * api-change:``cloudhsmv2``: Update cloudhsmv2 client to latest version
- from version 1.12.0
  * api-change:``logs``: Update logs client to latest version
  * api-change:``config``: Update config client to latest version
  * feature:Events: This migrates the event system to using sevice ids
    instead of either client name or endpoint prefix. This prevents issues
    that might arise when a service changes their endpoint prefix, also
    fixes a long-standing bug where you could not register an event to a
    particular service if it happened to share its endpoint prefix with
    another service (e.g. ``autoscaling`` and ``application-autoscaling``
    both use the endpoint prefix ``autoscaling``). Please see the `upgrade
    notes <https://botocore.amazonaws.com/v1/documentation/api/latest/index.html#upgrade-notes>`_
    to determine if you are impacted and how to proceed if you are.
- from version 1.11.9
  * api-change:``apigateway``: Update apigateway client to latest version
  * api-change:``codecommit``: Update codecommit client to latest version
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
- from version 1.11.8
  * api-change:``rds``: Update rds client to latest version
  * api-change:``s3``: Update s3 client to latest version
  * api-change:``appstream``: Update appstream client to latest version
  * api-change:``dynamodb``: Update dynamodb client to latest version
  * api-change:``elb``: Update elb client to latest version
- from version 1.11.7
  * api-change:``rds``: Update rds client to latest version
  * api-change:``rekognition``: Update rekognition client to latest version
- from version 1.11.6
  * api-change:``waf-regional``: Update waf-regional client to latest version
  * api-change:``waf``: Update waf client to latest version
  * api-change:``eks``: Update eks client to latest version
- from version 1.11.5
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``sagemaker``: Update sagemaker client to latest version
  * bugfix:signing: Fix an issue where mixed endpoint casing could cause a SigV4 signature mismatch.
- from version 1.11.4
  * api-change:``glue``: Update glue client to latest version
  * api-change:``sagemaker-runtime``: Update sagemaker-runtime client to latest version
  * api-change:``mediapackage``: Update mediapackage client to latest version
- from version 1.11.3
  * api-change:``glue``: Update glue client to latest version
  * api-change:``xray``: Update xray client to latest version
- from version 1.11.2
  * api-change:``iot``: Update iot client to latest version
  * api-change:``signer``: Update signer client to latest version
  * api-change:``redshift``: Update redshift client to latest version
  * api-change:``iotanalytics``: Update iotanalytics client to latest version
- Refresh patches for new version
  + hide_py_pckgmgmt.patch
- Update BuildRequires in spec file from setup.py
* Thu Sep 13 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Version update to 1.11.1 (bsc#1095041)
  * api-change:``glue``: Update glue client to latest version
- from version 1.11.0
  * api-change:``events``: Update events client to latest version
  * api-change:``cognito-idp``: Update cognito-idp client to latest version
  * feature:urllib3: The vendored version of requests and urllib3 are no longer being used and botocore now has a direct dependency on newer versions of upstream urllib3.
- from version 1.10.84
  * api-change:``iot``: Update iot client to latest version
  * api-change:``rekognition``: Update rekognition client to latest version
  * api-change:``lex-models``: Update lex-models client to latest version
  * api-change:``iotanalytics``: Update iotanalytics client to latest version
  * api-change:``medialive``: Update medialive client to latest version
- from version 1.10.83
  * api-change:``snowball``: Update snowball client to latest version
- from version 1.10.82
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``dlm``: Update dlm client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``elasticbeanstalk``: Update elasticbeanstalk client to latest version
- from version 1.10.81
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
  * api-change:``dynamodb``: Update dynamodb client to latest version
- from version 1.10.80
  * api-change:``dax``: Update dax client to latest version
  * api-change:``secretsmanager``: Update secretsmanager client to latest version
  * api-change:``sagemaker``: Update sagemaker client to latest version
- from version 1.10.79
  * api-change:``discovery``: Update discovery client to latest version
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``redshift``: Update redshift client to latest version
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
- from version 1.10.78
  * api-change:``devicefarm``: Update devicefarm client to latest version
- from version 1.10.77
  * api-change:``es``: Update es client to latest version
  * api-change:``autoscaling``: Update autoscaling client to latest version
  * api-change:``cloudfront``: Update cloudfront client to latest version
- from version 1.10.76
  * api-change:``sagemaker``: Update sagemaker client to latest version
- Drop obsolete patches
  + skip_test_on15.patch
- Refresh patches for new version
  + hide_py_pckgmgmt.patch
- Update BuildRequires in spec file from setup.py
- Update sed expression to patch out vendored modules
* Mon Aug 13 2018 rjschwei@suse.com
- Version update to 1.10.75
  + Remove fix_tests.patch
  + Add skip_test_on15.patch
  + api-change:rds: Update rds client to latest version
  + api-change:mediaconvert: Update mediaconvert client to latest version
- from version 1.10.74
  + api-change:rds: Update rds client to latest version
  + api-change:dax: Update dax client to latest version
  + api-change:ecs: Update ecs client to latest version
- from version 1.10.73
  + api-change:secretsmanager: Update secretsmanager client to latest version
  + api-change:ssm: Update ssm client to latest version
- from version 1.10.72
  + api-change:logs: Update logs client to latest version
  + api-change:codebuild: Update codebuild client to latest version
  + api-change:ssm: Update ssm client to latest version
  + api-change:ec2: Update ec2 client to latest version
  + api-change:pinpoint: Update pinpoint client to latest version
- from version 1.10.71
  + api-change:health: Update health client to latest version
  + api-change:dynamodb: Update dynamodb client to latest version
- from version 1.10.70
  + api-change:alexaforbusiness: Update alexaforbusiness client to latest
    version
- from version 1.10.69
  + api-change:polly: Update polly client to latest version
  + api-change:ssm: Update ssm client to latest version
  + api-change:kinesis: Update kinesis client to latest version
  + api-change:resource-groups: Update resource-groups client to latest version
- from version 1.10.68
  + api-change:storagegateway: Update storagegateway client to latest version
  + api-change:transcribe: Update transcribe client to latest version
- from version 1.10.67
  + api-change:kms: Update kms client to latest version
  + api-change:mediaconvert: Update mediaconvert client to latest version
  + api-change:es: Update es client to latest version
  + api-change:iot: Update iot client to latest version
  + api-change:connect: Update connect client to latest version
- from version 1.10.66
  + api-change:directconnect: Update directconnect client to latest version
  + api-change:glue: Update glue client to latest version
  + api-change:iot: Update iot client to latest version
  + api-change:cloudhsmv2: Update cloudhsmv2 client to latest version
  + api-change:sagemaker: Update sagemaker client to latest version
  + api-change:mq: Update mq client to latest version
  + enhancment:Timestamp Serialization: Support explicit timestamp
    serialization per timestamp shape.
  + api-change:glacier: Update glacier client to latest version
- from version 1.10.65
  + api-change:ssm: Update ssm client to latest version
  + api-change:ec2: Update ec2 client to latest version
  + api-change:greengrass: Update greengrass client to latest version
  + api-change:inspector: Update inspector client to latest version
  + api-change:codebuild: Update codebuild client to latest version
  + api-change:redshift: Update redshift client to latest version
- from version 1.10.64
  + api-change:ecs: Update ecs client to latest version
  + api-change:elbv2: Update elbv2 client to latest version
  + api-change:ec2: Update ec2 client to latest version
- from version 1.10.63
  + api-change:dynamodb: Update dynamodb client to latest version
* Fri Aug 10 2018 tchvatal@suse.com
- Run fdupes again
- Run tests again
- Remove python2-unittest2 dependency as it is not really needed
  (only required on python2.6)
* Fri Aug  3 2018 rjschwei@suse.com
- Hide the Python package management requirements
  + add hide_py_pckgmgmt.patch
- Remove the bundled requests and six module
* Fri Aug  3 2018 rjschwei@suse.com
- Remove the broken attempt to  avoid using the bundeled requests module
  provided by the source (boo#1088310)
* Sun Jul 22 2018 adrian.glaubitz@suse.com
- Version update to 1.10.62
  * api-change:``config``: Update config client to latest version
  * api-change:``dlm``: Update dlm client to latest version
- from version 1.10.61
  * api-change:``mediapackage``: Update mediapackage client to latest version
- from version 1.10.60
  * api-change:``iotanalytics``: Update iotanalytics client to latest version
- from version 1.10.59
  * api-change:``sagemaker``: Update sagemaker client to latest version
  * api-change:``polly``: Update polly client to latest version
  * api-change:``comprehend``: Update comprehend client to latest version
  * api-change:``snowball``: Update snowball client to latest version
- from version 1.10.58
  * api-change:``kinesisvideo``: Update kinesisvideo client to latest version
  * api-change:``appstream``: Update appstream client to latest version
  * api-change:``kinesis-video-archived-media``: Update kinesis-video-archived-media client to latest version
- from version 1.10.57
  * api-change:``iam``: Update iam client to latest version
  * api-change:``dlm``: Update dlm client to latest version
  * api-change:``appsync``: Update appsync client to latest version
  * api-change:``efs``: Update efs client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``emr``: Update emr client to latest version
- from version 1.10.56
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``s3``: Update s3 client to latest version
  * api-change:``apigateway``: Update apigateway client to latest version
  * api-change:``ce``: Update ce client to latest version
- from version 1.10.55
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``glue``: Update glue client to latest version
  * api-change:``opsworks``: Update opsworks client to latest version
  * api-change:``appstream``: Update appstream client to latest version
- from version 1.10.54
  * api-change:``application-autoscaling``: Update application-autoscaling client to latest version
- from version 1.10.53
  * api-change:``application-autoscaling``: Update application-autoscaling client to latest version
  * api-change:``lambda``: Update lambda client to latest version
  * api-change:``dms``: Update dms client to latest version
  * api-change:``ce``: Update ce client to latest version
  * api-change:``transcribe``: Update transcribe client to latest version
* Fri Jul 13 2018 adrian.glaubitz@suse.com
- Version update to 1.10.57
  * api-change:``iam``: Update iam client to latest version
  * api-change:``dlm``: Update dlm client to latest version
  * api-change:``appsync``: Update appsync client to latest version
  * api-change:``efs``: Update efs client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``emr``: Update emr client to latest version
- from version 1.10.56
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``s3``: Update s3 client to latest version
  * api-change:``apigateway``: Update apigateway client to latest version
  * api-change:``ce``: Update ce client to latest version
- from version 1.10.55
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``glue``: Update glue client to latest version
  * api-change:``opsworks``: Update opsworks client to latest version
  * api-change:``appstream``: Update appstream client to latest version
- from version 1.10.54
  * api-change:``application-autoscaling``: Update application-autoscaling client to latest version
- from version 1.10.53
  * api-change:``application-autoscaling``: Update application-autoscaling client to latest version
  * api-change:``lambda``: Update lambda client to latest version
  * api-change:``dms``: Update dms client to latest version
  * api-change:``ce``: Update ce client to latest version
  * api-change:``transcribe``: Update transcribe client to latest version
- from version 1.10.52
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
  * api-change:``serverlessrepo``: Update serverlessrepo client to latest version
- from version 1.10.51
  * api-change:``sagemaker``: Update sagemaker client to latest version
  * api-change:``pinpoint``: Update pinpoint client to latest version
- from version 1.10.50
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``redshift``: Update redshift client to latest version
  * api-change:``acm``: Update acm client to latest version
- from version 1.10.49
  * api-change:``ssm``: Update ssm client to latest version
- from version 1.10.48
  * api-change:``elasticbeanstalk``: Update elasticbeanstalk client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
  * api-change:``lambda``: Update lambda client to latest version
- from version 1.10.47
  * api-change:``cloudfront``: Update cloudfront client to latest version
  * api-change:``comprehend``: Update comprehend client to latest version
  * api-change:``codepipeline``: Update codepipeline client to latest version
  * api-change:``secretsmanager``: Update secretsmanager client to latest version
  * enhancement:StreamingResponses: Add ``iter_lines()`` and ``iter_chunks()`` to streaming responses (`#1195 <https://github.com/boto/botocore/issues/1195>`__)
- from version 1.10.46
  * api-change:``secretsmanager``: Update secretsmanager client to latest version
  * api-change:``s3``: Update s3 client to latest version
  * api-change:``inspector``: Update inspector client to latest version
- from version 1.10.45
  * api-change:``appstream``: Update appstream client to latest version
  * api-change:``alexaforbusiness``: Update alexaforbusiness client to latest version
- from version 1.10.44
  * api-change:``clouddirectory``: Update clouddirectory client to latest version
- from version 1.10.43
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``macie``: Update macie client to latest version
  * api-change:``neptune``: Update neptune client to latest version
- from version 1.10.42
  * api-change:``acm-pca``: Update acm-pca client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``medialive``: Update medialive client to latest version
- from version 1.10.41
  * api-change:``rekognition``: Update rekognition client to latest version
* Tue Jun 19 2018 adrian.glaubitz@suse.com
- Version update to 1.10.40:
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
- from version 1.10.39
  * api-change:``iotanalytics``: Update iotanalytics client to latest version
  * api-change:``dynamodb``: Update dynamodb client to latest version
  * api-change:``apigateway``: Update apigateway client to latest version
- from version 1.10.38
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
- from version 1.10.37
  * api-change:``ecs``: Update ecs client to latest version
  * api-change:``devicefarm``: Update devicefarm client to latest version
- from version 1.10.36
  * api-change:``storagegateway``: Update storagegateway client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``clouddirectory``: Update clouddirectory client to latest version
- from version 1.10.35
  * api-change:``mediatailor``: Update mediatailor client to latest version
- from version 1.10.34
  * api-change:``medialive``: Update medialive client to latest version
- from version 1.10.33
  * api-change:``polly``: Update polly client to latest version
  * api-change:``ce``: Update ce client to latest version
  * api-change:``secretsmanager``: Update secretsmanager client to latest version
  * api-change:``shield``: Update shield client to latest version
  * api-change:``rds``: Update rds client to latest version
- from version 1.10.32
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``sagemaker``: Update sagemaker client to latest version
  * api-change:``mgh``: Update mgh client to latest version
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
  * api-change:``appstream``: Update appstream client to latest version
  * api-change:``eks``: Update eks client to latest version
- from version 1.10.31
  * api-change:``ds``: Update ds client to latest version
  * api-change:``mediatailor``: Update mediatailor client to latest version
  * api-change:``sns``: Update sns client to latest version
  * api-change:``redshift``: Update redshift client to latest version
  * api-change:``iot``: Update iot client to latest version
- from version 1.10.30
  * api-change:``neptune``: Update neptune client to latest version
  * api-change:``elbv2``: Update elbv2 client to latest version
- from version 1.10.29
  * api-change:``pi``: Update pi client to latest version
- from version 1.10.28
  * api-change:``iot``: Update iot client to latest version
  * api-change:``config``: Update config client to latest version
  * api-change:``appstream``: Update appstream client to latest version
  * api-change:``glue``: Update glue client to latest version
- from version 1.10.27
  * api-change:``secretsmanager``: Update secretsmanager client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``elbv2``: Update elbv2 client to latest version
- from version 1.10.26
  * api-change:``inspector``: Update inspector client to latest version
  * enhancement:Credentials: Disable proxy configuration when fetching container credentials
  * api-change:``ecs``: Update ecs client to latest version
- from version 1.10.25
  * api-change:``cloudformation``: Update cloudformation client to latest version
- from version 1.10.24
  * api-change:``iot``: Update iot client to latest version
  * api-change:``ses``: Update ses client to latest version
- from version 1.10.23
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``cognito-idp``: Update cognito-idp client to latest version
  * api-change:``codedeploy``: Update codedeploy client to latest version
- from version 1.10.22
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
  * api-change:``secretsmanager``: Update secretsmanager client to latest version
- from version 1.10.21
  * api-change:``config``: Update config client to latest version
- from version 1.10.20
  * api-change:``organizations``: Update organizations client to latest version
  * api-change:``iot1click-devices``: Update iot1click-devices client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``iot1click-projects``: Update iot1click-projects client to latest version
- from version 1.10.19
  * api-change:``firehose``: Update firehose client to latest version
- from version 1.10.18
  * api-change:``gamelift``: Update gamelift client to latest version
- Update Requires in spec file from setup.py
* Thu May 10 2018 tchvatal@suse.com
- Create symlinks from system packages for the vendored stuff as some
  3rd party apps   require it and it leads to explosions
* Thu May 10 2018 tchvatal@suse.com
- Version update to 1.10.17:
  * api-change:rds: [botocore] Update rds client to latest version
  * api-change:ec2: [botocore] Update ec2 client to latest version
  * api-change:budgets: [botocore] Update budgets client to latest version
  * api-change:rds: [botocore] Update rds client to latest version
  * api-change:ec2: [botocore] Update ec2 client to latest version
  * api-change:alexaforbusiness: [botocore] Update alexaforbusiness client to latest version
  * api-change:s3: [botocore] Update s3 client to latest version
  * api-change:budgets: [botocore] Update budgets client to latest version
  * api-change:es: [botocore] Update es client to latest version
  * api-change:guardduty: [botocore] Update guardduty client to latest version
  * api-change:config: [botocore] Update config client to latest version
  * api-change:secretsmanager: [botocore] Update secretsmanager client to latest version
  * api-change:appsync: [botocore] Update appsync client to latest version
  * api-change:acm: [botocore] Update acm client to latest version
  * api-change:codepipeline: [botocore] Update codepipeline client to latest version
  * api-change:ssm: [botocore] Update ssm client to latest version
  * api-change:ec2: [botocore] Update ec2 client to latest version
  * api-change:guardduty: [botocore] Update guardduty client to latest version
  * api-change:alexaforbusiness: [botocore] Update alexaforbusiness client to latest version
  * api-change:route53domains: [botocore] Update route53domains client to latest version
  * api-change:workspaces: [botocore] Update workspaces client to latest version
  * api-change:sagemaker: [botocore] Update sagemaker client to latest version
  * api-change:dynamodb: [botocore] Update dynamodb client to latest version
  * api-change:glacier: [botocore] Update glacier client to latest version
  * api-change:secretsmanager: [botocore] Update secretsmanager client to latest version
  * api-change:rekognition: [botocore] Update rekognition client to latest version
  * api-change:xray: [botocore] Update xray client to latest version
  * api-change:codedeploy: [botocore] Update codedeploy client to latest version
  * api-change:secretsmanager: [botocore] Update secretsmanager client to latest version
  * api-change:elasticbeanstalk: [botocore] Update elasticbeanstalk client to latest version
  * api-change:iotanalytics: [botocore] Update iotanalytics client to latest version
  * api-change:iot: [botocore] Update iot client to latest version
  * api-change:autoscaling-plans: [botocore] Update autoscaling-plans client to latest version
  * api-change:medialive: [botocore] Update medialive client to latest version
  * api-change:firehose: [botocore] Update firehose client to latest version
  * api-change:ce: [botocore] Update ce client to latest version
  * api-change:codepipeline: [botocore] Update codepipeline client to latest version
  * api-change:ssm: [botocore] Update ssm client to latest version
  * api-change:ec2: [botocore] Update ec2 client to latest version
  * api-change:secretsmanager: [botocore] Update secretsmanager client to latest version
  * api-change:rds: [botocore] Update rds client to latest version
  * api-change:devicefarm: [botocore] Update devicefarm client to latest version
  * bugfix:dynamodb: Fixes a bug causing dynamodb operations with no output to throw errors.
* Thu Apr 19 2018 toddrme2178@gmail.com
- update to version 1.10.4
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``workmail``: Update workmail client to latest version
  * api-change:``dms``: Update dms client to latest version
  * api-change:``mediapackage``: Update mediapackage client to latest version
  * api-change:``glue``: Update glue client to latest version
- update to version 1.10.3
  * api-change:``clouddirectory``: Update clouddirectory client to latest version
* Sun Apr  8 2018 arun@gmx.de
- update linenumbers in patch
- update to version 1.10.2:
  * api-change:batch: Update batch client to latest version
- changes from version 1.10.1:
  * enhancementshield Added paginator for list_protections operation.
  * api-change:ssm: Update ssm client to latest version
- changes from version 1.10.0:
  * api-change:s3: Update s3 client to latest version
  * api-change:sagemaker: Update sagemaker client to latest version
  * api-change:acm: Update acm client to latest version
  * api-change:config: Update config client to latest version
  * api-change:transcribe: Update transcribe client to latest version
  * api-change:secretsmanager: Update secretsmanager client to latest
    version
  * api-change:acm-pca: Update acm-pca client to latest version
  * api-change:cloudwatch: Update cloudwatch client to latest version
  * feature:s3: Add support for S3 Select. Amazon S3 Select is an
    Amazon S3 feature that makes it easy to retrieve specific data
    from the contents of an object using simple SQL expressions
    without having to retrieve the entire object. With this release of
    the Amazon S3 SDK, S3 Select API (SelectObjectContent) is now
    generally available in all public regions. This release supports
    retrieval of a subset of data using SQL clauses, like SELECT and
    WHERE, from delimited text files and JSON objects in Amazon S3
    through the SelectObjectContent API available in AWS S3 SDK.
  * api-change:fms: Update fms client to latest version
- changes from version 1.9.23:
  * api-change:lambda: Update lambda client to latest version
  * api-change:devicefarm: Update devicefarm client to latest version
  * api-change:translate: Update translate client to latest version
- changes from version 1.9.22:
  * api-change:cloudfront: Update cloudfront client to latest version
  * api-change:apigateway: Update apigateway client to latest version
  * api-change:es: Update es client to latest version
- changes from version 1.9.21:
  * api-change:connect: Update connect client to latest version
  * api-change:acm: Update acm client to latest version
- changes from version 1.9.20:
  * api-change:greengrass: Update greengrass client to latest version
  * api-change:cloudformation: Update cloudformation client to latest
    version
  * api-change:ssm: Update ssm client to latest version
  * api-change:alexaforbusiness: Update alexaforbusiness client to
    latest version
- changes from version 1.9.19:
  * api-change:mturk: Update mturk client to latest version
  * api-change:sts: Update sts client to latest version
  * api-change:iam: Update iam client to latest version
- changes from version 1.9.18:
  * api-change:acm: Update acm client to latest version
- changes from version 1.9.17:
  * api-change:dynamodb: Update dynamodb client to latest version
  * bugfix:s3: Fix bug where invalid head_object requests would cause
    an infinite loop (alternate fix to #1400)
- changes from version 1.9.16:
  * api-change:rds: Update rds client to latest version
- changes from version 1.9.15:
  * api-change:ecs: Update ecs client to latest version
  * api-change:appstream: Update appstream client to latest version
  * api-change:codebuild: Update codebuild client to latest version
- changes from version 1.9.14:
  * bugfix:s3: Fix regression in redirects in using wrong region
- changes from version 1.9.13:
  * bugfix:s3: Fixed a bug where head object and bucket calls would
    attempt redirects incorrectly.
  * api-change:serverlessrepo: Update serverlessrepo client to latest
    version
- changes from version 1.9.12:
  * api-change:ce: Update ce client to latest version
  * enhancement:Credentials: Add the ability to disable fetching
    credentials from EC2 metadata by setting the environment variable
    AWS_EC2_METADATA_DISABLED to 'true'.
  * api-change:config: Update config client to latest version
  * api-change:elasticbeanstalk: Update elasticbeanstalk client to
    latest version
  * api-change:glue: Update glue client to latest version
  * api-change:medialive: Update medialive client to latest version
  * bugfix:Credentials: Fix a race condition related to assuming a
    role for the first time (#1405)
  * api-change:events: Update events client to latest version
  * api-change:ecs: Update ecs client to latest version
- changes from version 1.9.11:
  * api-change:elasticbeanstalk: Update elasticbeanstalk client to
    latest version
- changes from version 1.9.10:
  * api-change:sagemaker: Update sagemaker client to latest version
  * api-change:organizations: Update organizations client to latest
    version
  * api-change:pinpoint: Update pinpoint client to latest version
- changes from version 1.9.9:
  * api-change:lightsail: Update lightsail client to latest version
- changes from version 1.9.8:
  * api-change:servicediscovery: Update servicediscovery client to
    latest version
- changes from version 1.9.7:
  * api-change:cloudhsmv2: Update cloudhsmv2 client to latest version
  * api-change:discovery: Update discovery client to latest version
  * api-change:iot: Update iot client to latest version
  * api-change:redshift: Update redshift client to latest version
* Sun Mar 11 2018 sebix+novell.com@sebix.at
- update to version 1.9.6:
  * api-change:``pinpoint``: Update pinpoint client to latest version
  * api-change:``ecs``: Update ecs client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``mgh``: Update mgh client to latest version
- update to version 1.9.5:
  * api-change:``medialive``: Update medialive client to latest version
- update to version 1.9.4:
  * api-change:``ecs``: Update ecs client to latest version
- update to version 1.9.3:
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
  * api-change:``events``: Update events client to latest version
  * api-change:``storagegateway``: Update storagegateway client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
- update to version 1.9.2:
  * api-change:``application-autoscaling``: Update application-autoscaling client to latest version
- update to version 1.9.1:
  * api-change:``ecr``: Update ecr client to latest version
- update to version 1.9.0:
  * enhancement:Stubber: Added the ability to add items to response metadata with the stubber.
  * api-change:``sts``: Update sts client to latest version
  * api-change:``route53``: Update route53 client to latest version
  * feature:``s3``: Default to virtual hosted addressing regardless of signature version (boto/botocore`#1387 <https://github.com/boto/botocore/issues/1387>`__)
- update to version 1.8.50:
  * api-change:``appstream``: Update appstream client to latest version
- update to version 1.8.49:
  * api-change:``elbv2``: Update elbv2 client to latest version
  * api-change:``ce``: Update ce client to latest version
- update to version 1.8.48:
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``serverlessrepo``: Update serverlessrepo client to latest version
  * api-change:``codecommit``: Update codecommit client to latest version
- update to version 1.8.47:
  * api-change:``autoscaling``: Update autoscaling client to latest version
  * api-change:``waf-regional``: Update waf-regional client to latest version
  * api-change:``waf``: Update waf client to latest version
- update to version 1.8.46:
  * api-change:``config``: Update config client to latest version
- update to version 1.8.45:
  * api-change:``rds``: Update rds client to latest version
- update to version 1.8.44:
  * api-change:``mediaconvert``: Update mediaconvert client to latest version
  * api-change:``gamelift``: Update gamelift client to latest version
- update to version 1.8.43:
  * api-change:``appsync``: Update appsync client to latest version
  * api-change:``lex-models``: Update lex-models client to latest version
- update to version 1.8.42:
  * api-change:``glacier``: Update glacier client to latest version
  * api-change:``route53``: Update route53 client to latest version
- update to version 1.8.41:
  * api-change:``guardduty``: Update guardduty client to latest version
  * api-change:``cognito-idp``: Update cognito-idp client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``kms``: Update kms client to latest version
- update to version 1.8.40:
  * api-change:``lex-runtime``: Update lex-runtime client to latest version
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``lex-models``: Update lex-models client to latest version
- update to version 1.8.39:
  * api-change:``ds``: Update ds client to latest version
  * api-change:``appstream``: Update appstream client to latest version
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``budgets``: Update budgets client to latest version
  * api-change:``gamelift``: Update gamelift client to latest version
  * api-change:``dynamodb``: Update dynamodb client to latest version
  * api-change:``dms``: Update dms client to latest version
  * api-change:``mediastore``: Update mediastore client to latest version
- update to version 1.8.38:
  * api-change:``servicediscovery``: Update servicediscovery client to latest version
  * api-change:``servicecatalog``: Update servicecatalog client to latest version
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``glue``: Update glue client to latest version
- update to version 1.8.37:
  * api-change:``cloud9``: Update cloud9 client to latest version
  * api-change:``acm``: Update acm client to latest version
  * api-change:``kinesis``: Update kinesis client to latest version
  * api-change:``opsworks``: Update opsworks client to latest version
- update to version 1.8.36:
  * api-change:``mturk``: Update mturk client to latest version
  * api-change:``medialive``: Update medialive client to latest version
  * api-change:``devicefarm``: Update devicefarm client to latest version
- update to version 1.8.35:
  * api-change:``lambda``: Update lambda client to latest version
  * api-change:``codebuild``: Update codebuild client to latest version
  * api-change:``alexaforbusiness``: Update alexaforbusiness client to latest version
  * bugfix:Presign: Fix issue where some events were not fired during the presigning of a request thus not including a variety of customizations (`#1340 <https://github.com/boto/botocore/issues/1340>`__)
  * enhancement:Credentials: Improved error message when the source profile for an assume role is misconfigured. Fixes aws/aws-cli`#2763 <https://github.com/aws/aws-cli/issues/2763>`__
  * api-change:``guardduty``: Update guardduty client to latest version
  * enhancment:Paginator: Added paginators for a number of services where the result key is unambiguous.
- update to version 1.8.34:
  * api-change:``budgets``: Update budgets client to latest version
- update to version 1.8.33:
  * api-change:``glue``: Update glue client to latest version
  * api-change:``transcribe``: Update transcribe client to latest version
- update to version 1.8.32:
  * api-change:``sagemaker``: Update sagemaker client to latest version
- update to version 1.8.31:
  * api-change:``ec2``: Update ec2 client to latest version
  * api-change:``autoscaling-plans``: Update autoscaling-plans client to latest version
- update to version 1.8.30:
  * api-change:``application-autoscaling``: Update application-autoscaling client to latest version
  * api-change:``autoscaling-plans``: Update autoscaling-plans client to latest version
  * api-change:``rds``: Update rds client to latest version
- update to version 1.8.29:
  * api-change:``lambda``: Update lambda client to latest version
  * enhancement:cloudformation get_template template body ordering: fixes boto/boto3`#1378 <https://github.com/boto/boto3/issues/1378>`__
- update to version 1.8.28:
  * api-change:``glue``: Update glue client to latest version
- update to version 1.8.27:
  * api-change:``ssm``: Update ssm client to latest version
  * api-change:``elbv2``: Update elbv2 client to latest version
  * api-change:``rds``: Update rds client to latest version
  * api-change:``elb``: Update elb client to latest version
- remove port hide_py_pckgmgmt.patch
- add fix_tests.patch to fix tests for removed vendored packages
* Wed Jan 10 2018 adrian.glaubitz@suse.com
- update to version 1.8.26: (bsc#1075263)
  * api-change:kms: Update kms client to latest version
- changes from version 1.8.25:
  * api-change:ds: Update ds client to latest version
- changes from version 1.8.24:
  * api-change:route53: Update route53 client to latest version
  * api-change:discovery: Update discovery client to latest version
  * api-change:codedeploy: Update codedeploy client to latest version
- changes from version 1.8.23:
  * api-change:ssm: Update ssm client to latest version
  * api-change:inspector: Update inspector client to latest version
  * api-change:snowball: Update snowball client to latest version
- changes from version 1.8.22:
  * api-change:rds: Update rds client to latest version
- changes from version 1.8.21:
  * api-change:workspaces: Update workspaces client to latest version
- changes from version 1.8.20:
  * api-change:ecs: Update ecs client to latest version
  * api-change:ec2: Update ec2 client to latest version
  * api-change:inspector: Update inspector client to latest version
  * api-change:sagemaker: Update sagemaker client to latest version
- changes from version 1.8.19:
  * api-change:ec2: Update ec2 client to latest version
  * enhancement:Paginator: Added paginator support for lambda list aliases operation.
  * api-change:kinesisanalytics: Update kinesisanalytics client to latest version
  * api-change:codebuild: Update codebuild client to latest version
- changes from version 1.8.18:
  * api-change:iot: Update iot client to latest version
  * api-change:config: Update config client to latest version
- changes from version 1.8.17:
  * api-change:route53: Update route53 client to latest version
  * api-change:apigateway: Update apigateway client to latest version
  * api-change:mediastore-data: Update mediastore-data client to latest version
- changes from version 1.8.16:
  * bugfix:presigned-url: Fixes a bug where content-type would be set
    on presigned requests for query services.
  * api-change:cloudwatch: Update cloudwatch client to latest version
- changes from version 1.8.15:
  * api-change:appstream: Update appstream client to latest version
- changes from version 1.8.14:
  * api-change:ses: Update ses client to latest version
  * enhancement:credentials: Moved the JSONFileCache from the CLI into
    botocore so that it can be used without importing from the cli.
  * api-change:apigateway: Update apigateway client to latest version
- changes from version 1.8.13:
  * api-change:codedeploy: Update codedeploy client to latest version
  * bugfix:sagemaker-runtime: Renamed the runtime.sagemaker service to
    sagemaker-runtime to be more consistent with existing services. The
    old service name is now aliased to sagemaker-runtime to maintain
    backwards compatibility.
  * bugfix:Stubber: This change makes the error handling more verbose
    in the case where a stubbed method has been called, but the Stubber
    is not expecting a call.
  * api-change:workmail: Update workmail client to latest version
- changes from version 1.8.12:
  * api-change:sagemaker: Update sagemaker client to latest version
  * api-change:cognito-idp: Update cognito-idp client to latest version
  * api-change:lex-models: Update lex-models client to latest version
* Sat Dec  9 2017 arun@gmx.de
- update to version 1.8.11:
  * api-change:cloudwatch: Update cloudwatch client to latest version
  * api-change:appstream: Update appstream client to latest version
  * api-change:ecs: Update ecs client to latest version
- changes from version 1.8.10:
  * api-change:ses: Update ses client to latest version
  * api-change:es: Update es client to latest version
- changes from version 1.8.9:
  * api-change:elasticbeanstalk: Update elasticbeanstalk client to
    latest version
  * api-change:clouddirectory: Update clouddirectory client to latest
    version
- changes from version 1.8.8:
  * api-change:iot: Update iot client to latest version
  * api-change:servicediscovery: Update servicediscovery client to
    latest version
  * api-change:servicecatalog: Update servicecatalog client to latest
    version
- changes from version 1.8.7:
  * api-change:budgets: Update budgets client to latest version
  * api-change:ecs: Update ecs client to latest version
- changes from version 1.8.6:
  * api-change:cloud9: Update cloud9 client to latest version
  * api-change:lambda: Update lambda client to latest version
  * api-change:apigateway: Update apigateway client to latest version
  * api-change:alexaforbusiness: Update alexaforbusiness client to
    latest version
  * api-change:serverlessrepo: Update serverlessrepo client to latest
    version
  * api-change:ec2: Update ec2 client to latest version
- changes from version 1.8.5:
  * api-change:autoscaling: Update autoscaling client to latest
    version
  * api-change:waf: Update waf client to latest version
  * api-change:waf-regional: Update waf-regional client to latest
    version
  * api-change:resource-groups: Update resource-groups client to
    latest version
  * api-change:ssm: Update ssm client to latest version
  * api-change:lightsail: Update lightsail client to latest version
  * api-change:ec2: Update ec2 client to latest version
- changes from version 1.8.4:
  * api-change:kinesis-video-media: Update kinesis-video-media client
    to latest version
  * api-change:translate: Update translate client to latest version
  * api-change:sagemaker: Update sagemaker client to latest version
  * api-change:iot-jobs-data: Update iot-jobs-data client to latest
    version
  * api-change:s3: Update s3 client to latest version
  * api-change:ecs: Update ecs client to latest version
  * api-change:runtime.sagemaker: Update runtime.sagemaker client to
    latest version
  * api-change:kinesisvideo: Update kinesisvideo client to latest
    version
  * api-change:comprehend: Update comprehend client to latest version
  * api-change:greengrass: Update greengrass client to latest version
  * api-change:glacier: Update glacier client to latest version
  * api-change:kinesis-video-archived-media: Update
    kinesis-video-archived-media client to latest version
  * api-change:dynamodb: Update dynamodb client to latest version
  * bugfix:Credentials: Fixed a bug causing issues in configuring the
    process provider on windows when paths were used.
  * api-change:iot: Update iot client to latest version
  * api-change:rekognition: Update rekognition client to latest
    version
- changes from version 1.8.3:
  * api-change:apigateway: Update apigateway client to latest version
  * api-change:appsync: Update appsync client to latest version
  * api-change:cognito-idp: Update cognito-idp client to latest
    version
  * api-change:guardduty: Update guardduty client to latest version
  * api-change:batch: Update batch client to latest version
  * bugfix:rekognition: Fixed a bug causing the rekognition paginator
    to not return FaceModelVersions.
  * api-change:lambda: Update lambda client to latest version
  * api-change:mq: Update mq client to latest version
  * api-change:codedeploy: Update codedeploy client to latest version
  * bugfix:Credentials: Fixes an issue where cache keys would be too
    long to use as file names.
  * api-change:ec2: Update ec2 client to latest version
- changes from version 1.8.2:
  * api-change:mediapackage: Update mediapackage client to latest
    version
  * api-change:medialive: Update medialive client to latest version
  * api-change:mediastore: Update mediastore client to latest version
  * api-change:mediaconvert: Update mediaconvert client to latest
    version
  * api-change:mediastore-data: Update mediastore-data client to
    latest version
- changes from version 1.8.1:
  * bugfix:Credentials: Fixes a bug causing cached credentials to
    break in the CLI on Windows. Fixes aws/aws-cli`#2978
    <https://github.com/boto/botocore/issues/2978>`__
  * api-change:acm: Update acm client to latest version
- changes from version 1.8.0:
  * api-change:rekognition: Update rekognition client to latest
    version
  * api-change:emr: Update emr client to latest version
  * api-change:xray: Update xray client to latest version
  * feature:Credentials: When creating an assume role profile, you can
    now specify a credential source outside of the config file using
    the credential_source key.
  * api-change:shield: Update shield client to latest version
  * api-change:cloudformation: Update cloudformation client to latest
    version
  * feature:Credentials: When creating an assume role profile, you can
    now specify another assume role profile as the source. This allows
    for chaining assume role calls.
  * api-change:codebuild: Update codebuild client to latest version
  * feature:credentials: Adds support for the process credential
    provider, allowing users to specify a process to call to get
    credentials.
  * api-change:apigateway: Update apigateway client to latest version
  * api-change:storagegateway: Update storagegateway client to latest
    version
  * enhancement:Response: Allow reads of zero on streaming bodies,
    fixes #1309.
- changes from version 1.7.48:
  * api-change:workdocs: Update workdocs client to latest version
  * api-change:kinesis: Update kinesis client to latest version
  * api-change:codecommit: Update codecommit client to latest version
  * api-change:apigateway: Update apigateway client to latest version
  * api-change:firehose: Update firehose client to latest version
  * api-change:ce: Update ce client to latest version
* Sun Nov 19 2017 arun@gmx.de
- update to version 1.7.47:
  * api-change:s3: Update s3 client to latest version
  * api-change:dms: Update dms client to latest version
  * api-change:rds: Update rds client to latest version
  * api-change:elbv2: Update elbv2 client to latest version
  * api-change:application-autoscaling: Update application-autoscaling
    client to latest version
- changes from version 1.7.46:
  * api-change:opsworkscm: Update opsworkscm client to latest version
  * api-change:route53: Update route53 client to latest version
  * api-change:glue: Update glue client to latest version
  * api-change:organizations: Update organizations client to latest
    version
  * api-change:application-autoscaling: Update application-autoscaling
    client to latest version
  * api-change:ec2: Update ec2 client to latest version
- changes from version 1.7.45:
  * api-change:ses: Update ses client to latest version
  * api-change:apigateway: Update apigateway client to latest version
  * api-change:stepfunctions: Update stepfunctions client to latest
    version
  * api-change:polly: Update polly client to latest version
- changes from version 1.7.44:
  * api-change:ecs: Update ecs client to latest version
  * api-change:lightsail: Update lightsail client to latest version
  * api-change:ssm: Update ssm client to latest version
  * api-change:route53: Update route53 client to latest version
* Thu Nov  9 2017 rjschwei@suse.com
- Update to version 1.7.43
  + For details see  https://github.com/boto/botocore/blob/1.7.43/CHANGELOG.rst
  + Forward port hide_py_pckgmgmt.patch
  + Needed for aws-cli 1.11.185 (boo#1066528)
* Tue Sep 12 2017 rjschwei@suse.com
- Update to version 1.7.9
  + For details see  https://github.com/boto/botocore/blob/1.7.9/CHANGELOG.rst
  + Needed for aws-cli 1.11.151
* Fri Aug 25 2017 tbechtold@suse.com
- update to version 1.5.89
  * Bumping version to 1.5.88
  * Bumping version to 1.5.89
  * Add test for unsigned presign
  * Added release notes for Organizations paginators
  * Bumping version to 1.5.80
  * Bumping version to 1.5.81
  * Bumping version to 1.5.82
  * Bumping version to 1.5.83
  * Bumping version to 1.5.84
  * Bumping version to 1.5.85
  * Bumping version to 1.5.86
  * Bumping version to 1.5.87
  * Ensure header values are utf8 in signing string
  * Generate example enum
  * Added release notes for Athena paginators
  * Bumping version to 1.5.74
  * Remove _UNSIGNED from the namespace
  * Vendor six at version 1.10.0
  * Remove a bit of dead code from s3 presign default
  * Use assertEqual instead of deprecated assertEquals
  * Don't fail OpenSSL version check on 1.1.0
  * Move config check function to client module
  * Update kinesis non_aggregate_keys
  * Allow proxies to be set through the Config object.
  * Test restricted regions don't use virtual host
  * Fix SigV2Auth for GET requests
  * Add paginators for IoT list calls
  * Move sigv2 presign defaulting to client creator
  * Bumping version to 1.5.68
  * Bumping version to 1.5.69
  * Adding SSE related fields to Kinesis non_aggregate_keys
  * Add test for six.moves thread safety
  * Added paginators for the Organizations service
  * Added release notes for IoT paginators
  * Make copying UNSIGNED return the same instance
  * Add SSM describe_parameters paginator
  * Use sigv2 by default for presigning s3
  * Always use embedded URIs
  * Revert "Merge pull request #1208 from JordonPhillips/sv4-final"
  * Update to latest models
  * Remove unused import
  * Remove default value for deepcopy
  * Fix all invalid escape sequences discovered running tests
  * Revert "Merge branch 'revert-sigv4' into develop"
  * Update to latest endpoints
  * Discard starting_truncation after first request
  * Bumping version to 1.5.75
  * Bumping version to 1.5.79
  * Bumping version to 1.5.77
  * Bumping version to 1.5.76
  * Bumping version to 1.5.71
  * Bumping version to 1.5.70
  * Bumping version to 1.5.73
  * Bumping version to 1.5.72
  * Clean up all unused imports in tests
  * Added release notes for SSM paginator
  * Bumping version to 1.5.78
  * Enable pip cache in Travis CI builds
  * Use sigv4 by default for s3
  * added paginators for athena
* Wed Jun 14 2017 rjschwei@suse.com
- Update to version 1.5.67 (bsc#1044370)
  + For details see
    https://github.com/boto/botocore/blob/1.5.67/CHANGELOG.rst
* Wed May 10 2017 rjschwei@suse.com
- Fix source URL missing "/"
* Tue Feb 28 2017 toddrme2178@gmail.com
- Implement single-spec version.
- Fix source URL.
- Update to 1.5.47
  Too many changes to list, please see:
  https://github.com/boto/botocore/blob/1.5.47/CHANGELOG.rst
* Mon Jan  2 2017 dmueller@suse.com
- switch to pypi package and fix source url
* Thu Dec 15 2016 rjschwei@suse.com
- Update to bersion 1.4.86 (bsc#1015776)
  + feature:dms: Update dms client to latest version
  + feature:rds: Update rds client to latest version
  + feature:logs: Update logs client to latest version
  + feature:marketplacecommerceanalytics: Update marketplacecommerceanalytics
    client to latest version
  + feature:elasticbeanstalk: Update elasticbeanstalk client to latest version
  + feature:sts: Update sts client to latest version
  + feature:batch: Update batch client to latest version
- From 1.4.85
  + feature:cloudfront: Add lambda function associations to cache behaviors.
  + feature:rds: Add cluster create data to DBCluster APIs.
  + feature:waf-regional: With this new feature, customers can use AWS WAF
    directly on Application Load Balancers in a VPC within available regions
    to protect their websites and web services from malicious attacks such
    as SQL injection, Cross Site Scripting, bad bots, etc.
- From 1.4.84
  + feature:config: Update config client to latest version
  + feature:health: Add paginators for Health.
  + feature:sqs: Update sqs client to latest version
  + feature:s3: Update s3 client to latest version
- From 1.4.83
  + feature:pinpoint: Update pinpoint client to latest version
  + feature:ec2: Update ec2 client to latest version
  + feature:sts: Update sts client to latest version
  + feature:config: Update config client to latest version
- From 1.4.82
  + bugfix:Exceptions: Allow parsing of json error responses with non-json
    bodies.
  + feature:opsworks-cm: Added waiter for Opsworks CM
- From 1.4.81
  + feature:parameter: Automatically inject an idempotency token into
    parameters marked with the idempotencyToken trait
  + feature:appstream: Update appstream client to latest version
  + feature:directconnect: Update directconnect client to latest version
  + feature:elasticbeanstalk: Update elasticbeanstalk client to latest version
  + feature:shield: Update shield client to latest version
  + feature:opsworkscm: Update opsworkscm client to latest version
  + feature:lambda: Update lambda client to latest version
  + feature:codebuild: Update codebuild client to latest version
  + feature:xray: Update xray client to latest version
  + feature:stepfunctions: Update stepfunctions client to latest version
  + feature:ssm: Update ssm client to latest version
  + feature:health: Update health client to latest version
  + feature:ec2: Update ec2 client to latest version
  + feature:apigateway: Update apigateway client to latest version
  + feature:pinpoint: Update pinpoint client to latest version
- From 1.4.80
  + feature:lightsail: Update lightsail client to latest version
  + feature:polly: Update polly client to latest version
  + feature:snowball: Update snowball client to latest version
  + feature:rekognition: Update rekognition client to latest version
- From 1.4.79
  + bugfix:s3: fixes #1059 (presigned s3v4 URL bug related to blank query
    parameters being filtered incorrectly)
  + feature:s3: Update s3 client to latest version
  + bugfix:Presigner: Support presigning rest-json services.
- From 1.4.78
  + feature:s3: Update s3 client to latest version
  + feature:glacier: Update glacier client to latest version
  + feature:cloudformation: Update cloudformation client to latest version
  + feature:route53: Update route53 client to latest version
- From 1.4.77
  + feature:cloudtrail: Update cloudtrail client to latest version
  + feature:ecs: Update ecs client to latest version
- From 1.4.76
  + feature:application-autoscaling: Update application-autoscaling client
    to latest version
  + feature:elastictranscoder: Update elastictranscoder client to latest version
  + feature:lambda: Update lambda client to latest version
  + feature:emr: Update emr client to latest version
  + feature:gamelift: Update gamelift client to latest version
- From 1.4.75
  + feature:Loader: Support loading json extra files.
  + feature:meteringmarketplace: Update meteringmarketplace client to
    latest version
  + feature:cloudwatch: Update cloudwatch client to latest version
  + feature:apigateway: Update apigateway client to latest version
  + feature:sqs: Update sqs client to latest version
- From 1.4.74
  + feature:route53: Update route53 client to latest version
  + feature:servicecatalog: Update servicecatalog client to latest version
- From 1.4.73
  + feature:kinesis: Update kinesis client to latest version
  + feature:ds: Update ds client to latest version
  + feature:elasticache: Update elasticache client to latest version
- From 1.4.72
  + feature:cognito-idp: Update cognito-idp client to latest version
  + feature:Paginator: Add paginators for AWS WAF
- From 1.4.71
  + bugfix:Parsers: ResponseMetadata will now always be populated, provided
    the response was able to be parsed into a dict.
  + feature:cloudformation: Update cloudformation client to latest version
  + feature:logs: Update logs client to latest version
- From 1.4.70
  + feature:directconnect: Update directconnect client to latest version
- From 1.4.69
  + feature:ses: Update ses client to latest version
- From 1.4.68
  + feature:cloudformation: Update cloudformation client to latest version
  + feature:Stub: Made ANY usable for nested parameters
* Wed Oct 26 2016 rjschwei@suse.com
- Update to version 1.4.67 (bsc#1007084)
  + feature:elbv2: Update elbv2 client to latest version
  + feature:autoscaling: Update autoscaling client to latest version
- From 1.4.66
  + feature:sms: Update sms client to latest version
  + feature:ecs: Update ecs client to latest version
- From 1.4.65
  + bugfix:Waiters: Add back missing fail fail states to cloudformation
    waiters (#1056)
  + feature:waf: Update waf client to latest version
  + feature:budgets: Update budgets client to latest version
- From 1.4.64
  + feature:cloudfront: Update cloudfront client to latest version
  + feature:iot: Update iot client to latest version
  + feature:config: Update config client to latest version
  + feature:rds: Update rds client to latest version
  + feature:kinesisanalytics: Update kinesisanalytics client to latest version
- From 1.4.63
  + feature:route53: Update route53 client to latest version
  + feature:regions: Add support us-east-2
- From 1.4.62
  + feature:elasticbeanstalk: Update elasticbeanstalk client to latest version
  + feature:acm: Update acm client to latest version
  + feature:gamelift: Update gamelift client to latest version
- From 1.4.61
  + feature:ecr: Update ecr client to latest version
  + feature:cloudfront: Update cloudfront client to latest version
  + feature:codedeploy: Update codedeploy client to latest version
  + feature:sns: Update sns client to latest version
  + feature:apigateway: Update apigateway client to latest version
  + feature:Client Meta: Add partition to client meta object (#1027)
  + feature:elasticache: Update elasticache client to latest version
  + feature:kms: Update kms client to latest version
  + feature:rds: Update rds client to latest version
  + feature:gamelift: Update gamelift client to latest version
- From 1.4.60
  + feature:opsworks: Update opsworks client to latest version
  + feature:devicefarm: Update devicefarm client to latest version
  + feature:kms: Update kms client to latest version
  + feature:s3: Update s3 client to latest version
  + feature:waf: Update waf client to latest version
  + feature:cognito-idp: Update cognito-idp client to latest version
- From 1.4.58
  + feature:snowball: Update snowball client to latest version
  + feature:s3: Update s3 client to latest version
  + feature:ec2: Update ec2 client to latest version
- From 1.4.57
  + feature:cloudformation: Update cloudformation client to latest version
  + feature:codepipeline: Update codepipeline client to latest version
  + feature:kms: Update kms client to latest version
  + feature:efs: Update efs client to latest version
- From 1.4.56
  + feature:redshift: Update redshift client to latest version
  + feature:Stubber: Add ability to specify expected params when using
    add_client_error (#1025)
  + feature:emr: Update emr client to latest version
  + feature:codedeploy: Update codedeploy client to latest version
  + feature:rds: Update rds client to latest version
- From 1.4.55
  + feature:iot: Update iot client to latest version
  + feature:rds: Update rds client to latest version
- From 1.4.54
  + feature:EC2: Add NetworkAclExists waiter (#1019)
  + feature:Paginator: Add paginators for Application Auto Scaling
    service (#1029)
  + feature:Config: Add max_pool_connections to client config
    (#773, #766, #1026)
  + feature:ec2: Update ec2 client to latest version
  + feature:servicecatalog: Update servicecatalog client to latest version
- From 1.4.53
  + feature:support: Update support client to latest version
  + feature:cloudfront: Update cloudfront client to latest version
  + feature:sns: Update sns client to latest version
- From 1.4.52
  + feature:codepipeline: Update codepipeline client to latest version
  + feature:ec2: Update ec2 client to latest version
  + feature:rds: Update rds client to latest version
  + feature:sns: Update sns client to latest version
  + feature:ecr: Update ecr client to latest version
- From 1.4.51
  + feature:rds: Update rds client to latest version
  + feature:ResponseMetadata: Add MaxAttemptsReached and RetryAttempts keys
    to the returned ResonseMetadata dictionary (#1024, #965, #926)
  + feature:application-autoscaling: Update application-autoscaling client
    to latest version
  + feature:cognito-idp: Update cognito-idp client to latest version
  + feature:Waiters: Add last_response attribute to WaiterError (#1023, #957)
  + feature:config: Update config client to latest version
  + feature:gamelift: Update gamelift client to latest version
- From 1.4.50
  + feature:autoscaling: Update autoscaling client to latest version
  + feature:codepipeline: Update codepipeline client to latest version
  + feature:ssm: Update ssm client to latest version
  + feature:cloudfront: Update cloudfront client to latest version
  + feature:route53: Update route53 client to latest version
- From 1.4.49
  + feature:rds: Update rds client to latest version
  + feature:opsworks: Update opsworks client to latest version
- From 1.4.48
  + feature:ec2: Update ec2 client to latest version
  + feature:iam: Update iam client to latest version
  + feature:workspaces: Update workspaces client to latest version
- From 1.4.47
  + feature:elbv2: Update elbv2 client to latest version
  + feature:apigateway: Update apigateway client to latest version
  + feature:ecs: Update ecs client to latest version
  + feature:acm: Update acm client to latest version
  + feature:kms: Update kms client to latest version
- From 1.4.45
  + feature:kms: Update kms client to latest version
  + feature:kinesisanalytics: Update kinesisanalytics client to latest version
  + feature:autoscaling: Update autoscaling client to latest version
  + feature:elb: Update elb client to latest version
  + feature:ecs: Update ecs client to latest version
  + feature:s3: Add support for s3 dualstack configuration
  + feature:snowball: Update snowball client to latest version
  + feature:elbv2: Update elbv2 client to latest version
- From 1.4.44
  + feature:marketplacecommerceanalytics: Update marketplacecommerceanalytics
    client to latest version
  + feature:ecr: Update ecr client to latest version
  + feature:cloudfront: Update cloudfront client to latest version
- From 1.4.43
  + feature:lambda: Update lambda client to latest version
  + feature:gamelift: Update gamelift client to latest version
  + feature:rds: Update rds client to latest version
- From 1.4.42
  + bugfix:Serialization: Account for boolean in query string serialization
  + feature:rds: Update rds client to latest version
  + feature:iot: Update iot client to latest version
  + feature:ds: Update ds client to latest version
  + feature:meteringmarketplace: Update meteringmarketplace client to
    latest version
  + feature:route53domains: Update route53domains client to latest version
  + feature:application-autoscaling: Update application-autoscaling client
    to latest version
  + feature:emr: Update emr client to latest version
  + feature:cloudwatch: Update cloudwatch client to latest version
  + feature:logs: Update logs client to latest version
  + feature:machinelearning: Update machinelearning client to latest version
- From 1.4.41
  + feature:ds: Update ds client to latest version
  + feature:ses: Update ses client to latest version
  + bugfix:s3: S3 region redirector will now honor the orginial url scheme.
  + feature:sts: Update sts client to latest version
  + feature:cognito-idp: Update cognito-idp client to latest version
  + feature:ec2: Update ec2 client to latest version
  + feature:es: Update es client to latest version
  + feature:apigateway: Update apigateway client to latest version
  + bugfix:Credentials: Raise error when partial hard coded creds are
    provided when creating a client.
- From 1.4.40
  + feature:s3: Update s3 client to latest version
  + feature:codedeploy: Add a waiter to wait on successful deployments.
  + feature:iot: Update iot client to latest version
- From 1.4.39
  + feature:acm: Update acm client to latest version
  + feature:elastictranscoder: Update elastictranscoder client to latest
    version
  + feature:cloudformation: Update cloudformation client to latest version
  + feature:config: Update config client to latest version
  + feature:application-autoscaling: Update application-autoscaling client
    to latest version
- From 1.4.38
  + feature:ssm: Update ssm client to latest version
  + feature:devicefarm: Update devicefarm client to latest version
- From 1.4.37
  + feature:dms: Update dms client to latest version
  + feature:ecs: Update ecs client to latest version
  + Feature:Credential Provider: Add support for ECS metadata credential
    provider.
  + feature:rds: Update rds client to latest version
- From 1.4.36
  + feature:servicecatalog: Update servicecatalog client to latest version
  + feature:opsworks: Update opsworks client to latest version
  + feature:ds: Update ds client to latest version
  + feature:config: Update config client to latest version
- From 1.4.35
  + feature:iam: Update iam client to latest version
  + feature:codepipeline: Update codepipeline client to latest version
  + feature:efs: Update efs client to latest version
- From 1.4.34
  + feature:dms: Update dms client to latest version
  + feature:ssm: Update ssm client to latest version
- From 1.4.33
  + feature:sns: Update sns client to latest version
  + feature:route53: Update route53 client to latest version
  + feature:ec2: Update ec2 client to latest version
  + feature:gamelift: Update gamelift client to latest version
  + feature:efs: Update efs client to latest version
  + feature:iot: Update iot client to latest version
- From 1.4.32
  + bugfix:S3: Fixed a bug where the S3 region redirector was potentially
    causing a memory leak on python 2.6.
  + feature:s3: Update s3 client to latest version
- From 1.4.31
  + bugfix:RequestSigner: RequestSigner.generate_presigned_url now requires
    the operation name to be passed in. This does not affect using
    generate_presigned_url through a client.
  + feature:rds: Update rds client to latest version
  + feature:directconnect: Update directconnect client to latest version
  + feature:RequestSigner: Allow botocore.UNSIGNED to be used with
    generate_presigned_url and generate_presigned_post.
  + feature:ec2: Update ec2 client to latest version
  + feature:cognito-identity: Update cognito-identity client to latest version
  + feature:iam: Update iam client to latest version
- From1.4.30
  + bugfix:AssumeRole: Fix regression introduced in #920 where assume role
    responses error out when attempting to cache a response. (#961)
- From 1.4.29
  + feature:ResponseMetadata: Add http response headers to the response
    metadata.
  + feature:codepipeline: Update codepipeline client to latest version
  + feature:s3: Automatically redirect S3 sigv4 requests sent to the wrong
    region.
  + feature:opsworks: Update opsworks client to latest version
  + feature:s3: Use MD5 to sign S3 bodies by default.
  + bugfix:EC2: Replace chars in the EC2 console output we can't decode
    with replacement chars. We were previously returning either the decoded
    content or the original base64 encoded content. We now will consistently
    return decoded output, any any chars we can't decode are substituted
    with a replacement char. (#953)
* Tue Jun 21 2016 rjschwei@suse.com
- Update to version 1.4.28 (bsc#985858)
  + feature:cloudtrail: Update cloudtrail client to latest version
  + feature:acm: Update acm client to latest version
  + bugfix:Stubber: Fix regression in comparing multiple expected parameters
  + feature:rds: Update rds client to latest version
  + feature:ses: Update ses client to latest version
- From 1.4.27
  + feature:Stubber: Allow certain paramters to be ignored by specifying
    stub.ANY. Resolves #931
  + feature:s3: Update s3 client to latest version
- From 1.4.26
  + feature:Config: Add parameter_validation option in config file to
    disable parameter validation when making API calls (#905)
  + feature:dynamodbstreams: Update dynamodbstreams client to latest version
  + bugfix:s3: Make the stubber work with get_bucket_location
  + feature:iot: Update iot client to latest version
  + feature:machinelearning: Update machinelearning client to latest version
- From 1.4.25
  + feature:Stubber: Allow adding additional keys to the service error
    response.
  + feature:ec2: Update ec2 client to latest version
  + feature:application-autoscaling: Update application-autoscaling
    client to latest version
* Thu Jun  2 2016 jacobwinski@gmail.com
- Update to version 1.4.24
  + feature:elasticache: Update elasticache client to latest version
- Update to version 1.4.23
  + feature:rds: Update rds client to latest version
  + feature:ec2: Update ec2 client to latest version
- Update to version 1.4.22
  + feature:firehose: Update firehose client to latest version
  + feature:ec2: Update ec2 client to latest version
  + feature:ecs: Update ecs client to latest version
- Update to version 1.4.21
  + feature:application-autoscaling: Adds support for Application Auto Scaling. Application Auto Scaling is a general purpose Auto Scaling service for supported elastic AWS resources. With Application Auto Scaling, you can automatically scale your AWS resources, with an experience similar to that of Auto Scaling.
  + feature:endpoints: Updated endpoints.json to latest.
- Update to version 1.4.20
  + feature:dynamodb: Update dynamodb client to latest version
  + bugfix:Waiters: Fix JMESPathTypeError exception being raised (#906, #907)
  + feature:workspaces: Update workspaces client to latest version
  + feature:s3: Add paginator for ListObjectsV2
  + feature:discovery: Update discovery client to latest version
  + feature:iam: Add missing paginators. Fixes #919.
- Update to version 1.4.19
  + feature:ec2: Update ec2 client to latest version
  + feature:ssm: Update ssm client to latest version
  + feature:discovery: Update discovery client to latest version
  + feature:cloudformation: Update cloudformation client to latest version
- Update to version 1.4.18
  + feature:storagegateway: Update storagegateway client to latest version
  + feature:directconnect: Update directconnect client to latest version
  + feature:emr: Update emr client to latest version
  + feature:sqs: Update sqs client to latest version
  + feature:iam: Update iam client to latest version
- Update to version 1.4.17
  + feature:kms: Update kms client to latest version
  + feature:sts: Update sts client to latest version
  + feature:apigateway: Update apigateway client to latest version
  + feature:ecs: Update ecs client to latest version
  + feature:s3: Update s3 client to latest version
  + feature:cloudtrail: Update cloudtrail client to latest version
- Update to version 1.4.16
  + feature:inspector: Update inspector client to latest version
  + feature:codepipeline: Update codepipeline client to latest version
  + feature:opsworks: Add InstanceRegistered waiter
  + feature:elasticbeanstalk: Update elasticbeanstalk client to latest version
- Update to version 1.4.15
  + feature:route53domains: Update route53domains client to latest version
  + feature:opsworks: Update opsworks client to latest version
- Update to version 1.4.14
  + feature:ecr: Update ecr client to latest version
  + bugfix:aws kinesis: Fix issue where "EnhancedMonitoring" was not displayed when running aws kinesis describe-stream (#1929)
  + feature:acm: Update acm client to latest version
  + feature:ec2: Update ec2 client to latest version
  + feature:sts: Update sts client to latest version
  + bugfix:Serializer: In the rest xml parser, we were converting the input we recieve into a str, which was causing failures on python 2 when multibyte unicode strings were passed in. The fix is to simply use six.text_type, which is unicode on 2 and str on 3. The string will be encoded into the default encoding later on in the serializer. Fixes #868
  + feature:cognito-idp: Update cognito-idp client to latest version
- Update to version 1.4.13
  + feature:EMR: Add support for smart targeted resize feature
  + feature:IOT: Add SQL RulesEngine version support
  + feature:ACM: Add tagging support for ACM
- Update to version 1.4.12
  + bugfix:Credentials: Include timezone information when storing refresh time (#869)
  + feature:EC2: Add support for two new EBS volume types
  + feature:S3: Add support for s3 accelerate configuration
  + feature:CognitoIdentityProvider: Add support for new service, CognitoIdedentityProvider
  + feature:S3: Add support for Amazon S3 Transfer Acceleration
  + feature:CodeCommit: Add paginators for CodeCommit (#881)
  + feature:Kinesis: Update Kinesis client to latest version
  + feature:ElasticBeanstalk: Add support for automatic platform version upgrades with managed updates
  + feature:DeviceFarm: Update DeviceFarm client to latest version
  + feature:FireHose: Update FireHose client to latest version
- Update to version 1.4.11
    feature:IoT: Add methods for managing CA certificates.
    bugfix:EC2: Fix issues with checking an incorrect error code in waiters.
    bugfix:Accept Header: Fix issue in overriding Accept header for API Gateway.
* Fri Apr  8 2016 rjschwei@suse.com
- Update to version 1.4.10 (bsc#974705)
  + feature:Lambda: Added support for setting the function runtime as
    nodejs4.3, as well as updating function configuration to set the runtime.
  + feature:DS: Added support for Directory Service Conditional Forwarder APIs.
  + feature:Elasticbeanstalk: Adds support for three additional elements in
    AWS Elasticbeanstalk's DescribeInstancesHealthResponse: Deployment,
    AvailabilityZone, and InstanceType. Additionally adds support for
    increased EnvironmentName length from 23 to 40.
  + bugfix:Paginator: Allow non-specified input tokens in old starting
    token format.
- From 1.4.9
  + feature:APIGateway: Added support for API Import
  + feature:Route53: Added support for metric-based health checks and
    regional health checks.
  + feature:STS: Added support for GetCallerIdentity, which returns details
    about the credentials used to make the API call. The details include
    name and account, as well as the type of entity making the call, such
    as an IAM user vs. federated user.
  + feature:S3: Added support for VersionId in PutObjectAcl (issue 856)
  + bugfix:S3: Add validation to enforce S3 metadata only contains ASCII.
    (issue 861)
  + bugfix:Exceptions: Consistently parse errors with no body (issue 859)
  + bugfix:Config: Handle case where S3 config key is not a dict (issue 858)
  + bugfix:Examples: Account for empty input shape in examples (issue 855)
- From 1.4.8
  + feature:ACM: Update client to latest version
  + feature:CloudFormation: Update client to latest version
  + feature:CodeDeploy: Update client to latest version
  + feature:DMS: Update client to latest version
  + feature:ElastiCache: Update client to latest version
  + feature:Elastic Beanstalk: Update client to latest version
  + feature:Redshift: Update client to latest version
  + feature:WAF: Update client to latest version
  + bugfix:Pagintor: Fix regression when providing a starting token for a
    paginator (issue 849)
  + bugfix:Response Parsing: Handle case when generic HTML error response
    is received (issue 850)
  + bugfix:Request serialization: Handle case when non str values are
    provided for header values when using signature version 4 (issue 852)
  + bugfix:Retry: Retry HTTP responses with status code 502 (issue 853)
- From 1.4.7
  + feature:ElastiCache: Update client to latest version
  + feature:RDS: Update client to latest version
  + feature:StorageGateway: Update client to latest version
  + bugfix: Handle case where error response from proxy is received
    (`issue 850 <https://github.com/boto/botocore/pull/850`__)
- From 1.4.6
  + feature:DeviceFarm: Add support to pay a flat monthly fee for unlimited
    testing of your Android and iOS apps with AWS Device Farm device slots
  + feature:RDS: Add support for customizing the order in which Aurora
    Replicas are promoted to primary instance during a failover
  + bugfix:Signature Version 4: Fix issue when calculating signature
    version 4 signature for certain urls (issue 827)
- From 1.4.5
  + feature:MeteringMarketplace: The AWS Marketplace Metering Service
    enables sellers to price their products along new pricing dimensions.
    After a integrating their product with the AWS Marketplace Metering
    Service, that product will emit an hourly record capturing the usage of
    any single pricing dimension. Buyers can easily subscribe to software
    priced by this new dimension on the AWS Marketplace website and only
    pay for what they use.
  + feature:S3: Added support for delete marker and abort multipart upload
    lifecycle configuration.
  + feature:IOT: Added support for Amazon Elasticsearch Service and Amazon
    Cloudwatch actions for the AWS IoT rules engine.
  + feature:CloudHSM: Added support for tagging resources.
- From 1.4.4
  + feature:DMS: Added support for AWS Database Migration Service
  + feature:SES: Added support for white-labeling
  + feature:CodeDeploy: Added support for BatchGetDeploymentGroups
  + feature:endpoints: Updated endpoints.json to latest version
- From 1.4.3
  + feature:GameLift: Update model to latest version
  + feature:IAM: Update model to latest version
  + feature:Redshift: Update model to latest version
- From 1.4.2
  + feature:ACM: Update model to latest version
  + feature:CodeCommit: Update model to latest version
  + feature:Config: Update model to latest version
  + feature:DeviceFarm: Update model to latest version
  + feature:DirectConnect: Update model to latest version
  + feature:Events: Update model to latest version
  + bugfix:DynamoDB Local: Fix issue when using the local region with
    dynamodb (issue 819)
  + bugfix:CloudSearchDomain: Fix issue when signing requests for
    cloudsearchdomain (boto3 issue 538)
- From 1.4.1
  + feature:Config: Moved Config to its own class to boost import speed
  + feature:EC2: Add support for VPC peering with security groups.
  + feature:DirectoryService: Add SNS event notification support
- From 1.4.0
  + feature:Regions: Add ability to list regions and endpoints for services
    in a partition. (issue 812)
  + feature:DynamoDB: Add support for DescribeLimits.
  + feature:APIGateway: Add support for TestInvokeAuthorizer and
    FlushStageAuthorizersCache operations.
  + feature:CloudSearchDomain: Add support for stats.
- From 1.3.28
  + feature:StorageGateway: Added support for user-supplied barcodes.
  + feature:CodeDeploy: Added support for setting up triggers for a
    deployment group.
  + bugfix:SSL: Fixed issue where AWS_CA_BUNDLE was not being used.
- From 1.3.27
  + feature:RDS: Added support for Cross-account Encrypted (KMS) snapshot
    sharing.
  + feature:EMR: Added support for adding EBS storage to EMR instances.
  + bugfix:pagination: Refactored pagination to handle non-string service
    tokens.
  + bugfix:credentials: Fix race condition in credential provider.
- No upstream changelogs prior to 1.3.27
* Wed Mar 16 2016 toddrme2178@gmail.com
- Change python-dateutil dependency to renamed python-python-dateutil
* Mon Feb  1 2016 toddrme2178@gmail.com
- Update to version 1.3.23
  + No upstream changelog
* Wed Jan 20 2016 rjschwei@suse.com
- spec file improvements
* Thu Dec 10 2015 rjschwei@suse.com
- Update to version 1.3.12 (bsc#958686)
  + No upstream changelog
* Tue Nov 17 2015 tbechtold@suse.com
- update to 1.3.7:
  + No upstream changelog
- Adjust Requires for python-docutils according to requires.txt
* Sat Oct 10 2015 rjschwei@suse.com
- Update to version 1.2.10 (bsc#949877)
  + No upstream changelog
- Forward port hide_py_pckgmgmt.patch
* Thu Aug  6 2015 rjschwei@suse.com
- Update to version 1.1.6 (fate#318337, bsc#905354)
  + Updating devicefarm
  + Promote 2 functions from JSONParser to BaseJSONParser
  + No upstream changelog for changes between 1.0.0.a3 and 1.1.5
- Forward port hide_py_pckgmgmt.patch
* Mon Jun  1 2015 rjschwei@suse.com
- Update to version 1.0.0.a3 (alpha 3)
  + Fixes issue with APi inconsistency on seesion implementation
* Wed May 27 2015 rjschwei@suse.com
- Update to version 1.0.0.a2 (alpha 2)
  + Update models to the latest version
  + Rename event to provide-client-params
  + Add client-method-called event to botocore
  + Update README with date of first alpha release
* Sun Apr 26 2015 benoit.monin@gmx.fr
- update to version 0.105.0: no upstream changelog
- point source URL to pypi
- increase minimum required version of python-jmespath to 0.6.2
- remove python as BuildRequires, unneeded
- add fdupes as BuildRequires and call it after install
* Wed Mar 25 2015 aboe76@gmail.com
- Updated to version 0.97.0
  + Upstream remove CONTRIBUTING.rst and NOTICE from tarball
  + Updated hidepypckgmgmt.patch for latest version
  + there is no upstream changelog
* Sun Jan 18 2015 rschweikert@suse.com
- Update to version 0.82.0
  + there is no upstream changelog
  + update in support for fix of bnc#905354
* Thu Oct 23 2014 rschweikert@suse.com
- Update to version 0.67.0
  + there is no upstream changelog
* Wed Feb 26 2014 rschweikert@suse.com
- Update to version 0.33
  + There is no upstream change log
  + Code license changed to Apache-2.0 from MIT
- Include in SLE 12 (FATE #315990)
* Sat Jan 18 2014 rschweikert@suse.com
- Update to version 0.30
  + There is no upstream change log
  + listing the git log between previous version 0.17.0 and this 0.30.0
    is too exhaustive
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Sun Sep 22 2013 aboe76@gmail.com
- Version 0.17.0 released
- Updateds ot s3-model/opsworks-model
- fix aws cli issues
* Wed Sep 11 2013 aboe76@gmail.com
- Updated package to version 0.16.0
- A lot of updates, still no changelog found
- see https://github.com/boto/botocore for more information
* Tue May  7 2013 aboe76@gmail.com
- Updated package to version 0.9.2
- eu-west-1 region support
- added support service
* Mon Apr 15 2013 aboe76@gmail.com
- Updated package python-botocore 0.9.0
- no changelog found
* Fri Feb 15 2013 aboe76@gmail.com
- initial package python-botocore 0.5.4
